import { QaBox } from "../components/Boxes";
import { TabScrollLink } from "../components/Link";
import { ScrollLinkWithChild } from "../components/ScrollLink";
import JoshuaInterviewSources from "../sources/joshua-inv-sources";
import MattijsInterviewSources from "../sources/mattij-inv-sources";
import RnhaleSources from "../sources/rnhale-sources";
import WischmeyerSources from "../sources/wimscheyer-sources";
import { useNavigation } from "../utils";


export function cellCultures () {
  const {goToPageAndScroll} = useNavigation();

  return (<a onClick={() => goToPageAndScroll('hek293-and-hek293t-cell-lines', '/materials-methods')}> linktext </a> );
}

export interface TimelineDatenpunkt {
  title?: string; /* Prof. , Dr., ... */
  vorname: string; 
  nachnname: string; 
  pictureurl: string; 
  tag: StakeholderTag; 
  heading: string; 
  interviewtabid: string; 
  type?: TypeTag; /* nur falls es ein meta tag ist  */
  affiliation?: string; 
  job?: string; 
  cardtext: string; 
  language?: Language; 
  quote: string; 
  quoteVorname?: string; /* Wenn die quote nicht von der Person ist über die der Text ist  */
  quoteNachname?: string; 
  aimofcontact: string | Array<string> | Array<React.ReactNode>; /* Sobald Zitierungen drin sind oder Links muss es HTML Code sein, ansonsten gehen strings */
  insights: string | Array<string> | Array<React.ReactNode>; /* Sobald Zitierungen drin sind oder Links muss es HTML Code sein, ansonsten gehen strings */
  clarification?: string | Array<string> | Array<React.ReactNode>; /* Sobald Zitierungen drin sind oder Links muss es HTML Code sein, ansonsten gehen strings */
  implementation: string | Array<string> | Array<React.ReactNode>; /* Sobald Zitierungen drin sind oder Links muss es HTML Code sein, ansonsten gehen strings */
  pictureurl_interview?: string;  /* Picture that goes into the paragraph "Insights"  */
  pictureurl_aim?: string;  /* Picture that goes into the paragraph "Aim of contact"  */
  pictureurl_implementation?: string;  /* Picture that goes into the paragraph "Implementation"  */
  more_pictures?: Array<string> ;
  references?: React.ReactNode;  /* Muss HTML Code sein - Liliana erstellt den aus Bib dateien */
  interview?: React.ReactNode; 
  text?: string | Array<string> | Array<React.ReactNode>; /* Extra Text */
  experton?: string;  
  summary: string; 
  months: string, 
}

type StakeholderTag = 'Industry' | 'Academia' | 'Patient' | 'Medical Professional' | 'Milestone' | 'Other'; 
type TypeTag = 'meta' | 'kaya' ; 
type Language = 'en' | 'de'; 

 

const pics: { [key: string]: string } = {
  placeholder: "https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg",
  max: "https://static.igem.wiki/teams/5247/photos/hp/hp-max-portrait.jpg",
  kristian: "https://static.igem.wiki/teams/5247/photos/hp/kristian.jpeg",
  olariu: "https://static.igem.wiki/teams/5247/photos/hp/olariu-cristian.jpg",
  westhoff: "https://static.igem.wiki/teams/5247/photos/hp/hp-katrin-portrait.jpg",
  mattijs: "https://static.igem.wiki/teams/5247/photos/hp/mattijs.jpg",
  julia: "https://static.igem.wiki/teams/5247/photos/hp/julia.jpg",
  kolonko: "https://static.igem.wiki/teams/5247/photos/hp/kolonko-neu.jpg",
  svenja: "https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg",
  berens: "https://static.igem.wiki/teams/5247/photos/hp/berens.jpg",
  draeger: "https://static.igem.wiki/teams/5247/photos/hp/oliver-draeger-patch-clamp.jpeg",
  winkeljann: "https://static.igem.wiki/teams/5247/photos/hp/rnhale-winkeljann.jpg",
  kuehnel: "https://static.igem.wiki/teams/5247/photos/hp/hp-philippk-hnel.jpeg ",
  wischmeyer: "https://static.igem.wiki/teams/5247/photos/hp/wischmeyer-erhard.webp",
  nicole: "https://static.igem.wiki/teams/5247/photos/hp/hp-friedlein-nicole.jpg",
  joshua: "https://static.igem.wiki/teams/5247/photos/hp/joshua.jpg",
  hammer: "https://static.igem.wiki/teams/5247/photos/hp/hp-hammer.webp",
  johannfunke: "https://static.igem.wiki/teams/5247/photos/hp/hp-michaeljohannfunke.webp",
  kühnel: "https://static.igem.wiki/teams/5247/photos/hp/hp-philippk-hnel.jpeg ",
};

/* {
    vorname: "",
    nachnname: "",  
    pictureurl: pics['placeholder'],
    tag: "",
    heading: "",
    interviewtabid: "",
    cardtext: "",
    language: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
  } */


    /* WICHTIG!
      Fehlende Infos einfach leer lassen und keine Dummy-Texte einfügen! 
    */

export const timelinedata: Array<TimelineDatenpunkt>  = [
  {
    vorname: "Building the team",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    heading: "Development of a multidisciplinary team structure",
    interviewtabid: "recruiting",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: "February"
  },
  {
    vorname: "Pitching ideas",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    heading: "Getting Acquainted with Cystic Fibrosis",
    interviewtabid: "firstpresi",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: ""
  },
  {
    vorname: "Ideation",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    heading: "Brainstorming and selection of ideas and concepts",
    interviewtabid: "ideas",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: ""
  },
  {
    title: "Prof. Dr.",
    vorname: "Kristian",
    nachnname: "Müller",
    job: "Research Group Cellular and Molecular Biotechnology",
    affiliation: "Technical Faculty of Bielefeld University",
    pictureurl: pics['kristian'],
    tag: "Academia",
    heading: "Discussion about the delivery method- AVV vs. LNPs",
    interviewtabid: "kristian",
    cardtext: "",
    language: "de",
    quote: "X",
    aimofcontact: "X",
    insights: "X",
    implementation: "X",
    summary: "",
    months: ""
  },
  {
    vorname: "Max",
    nachnname: "Beckmann",
    job: "Bielefeld University",
    affiliation: "Patient and Student of Bielefeld University",
    pictureurl: pics['max'],
    tag: "Patient",
    heading: "Gathering valuable insights from the patient’s perspective",
    interviewtabid: "maxfirst",
    cardtext: "",
    language: "de",
    quote: "A friend of mine with cystic fibrosis recently got a fungal infection that he can't get rid of. His situation really struck me; it showed how quickly a seemingly minor issue can worsen a person's life, especially for someone like us. It’s a strong reminder of how fragile our health is and how fast things can change without warning.",
    aimofcontact: [<p>When cystic fibrosis came up as a possible topic, we reached out to a teammate's friend Max in the hopes of getting insights into the needs of CF patients and current treatments to verify the need for further treatment options.
      Since he was much more enthusiastic and open for discussion than we dared to hope, we extended our exchanges into the realms of the reality of life for CF patients, possible progressions, organizations and doctors in our area and his personal perspectives and values.
      The interest in meeting him grew in the whole team and we invited him to one of our meetings.   </p>],
    insights: [<><p>His honest and open answers to us, mostly nothing more than strangers to him, were touching and let the seriousness of cystic fibrosis set in.
      Learning about the challenges he faced felt heavy, besides him being in relatively good health and having a good life quality for a CF patient.
    </p>
      <p>Additional to the interpersonal effects of our discussion, Max gave us the reasons to continue with gene therapy approach while focusing on the lung:
        Modulators do not erase all symptoms.
        There is a keen interest for new treatments in the CF community.
        The the decreasing lung functionality it the most limiting.
        The immense impact of treatments on the life quality.  </p>
      <p>We learned a lot of new things that we did not consider before about cystic fibrosis such as:
        The need for a calorie rich diet and digestive problems.
        The frequency of checkups needed.
        How vastly different the progressions can be.
        The increased need for hygiene to prevent infections.
        The high price of medicines and induvial therapeutics. </p>
      <p>Afterwards, we reflected on the discussion and asked our team members what stuck with them:
        “How much attention has to be paid to everything in everyday life, I hadn't even thought about problems at the hairdresser.”
        “Simply that he was there and reported everything in such detail. From minute 1, I had permanent goosebumps because I was so moved by this story. I think it's great how he stands his ground in life, does what he wants to do and what defines him as a person. It didn't seem as if his life was determined by CF. I somehow expected it to be different, even if that sounds a bit silly.”
        “The amount of medication and how expensive it is.”
        "The statement that left the biggest impression for me was when Max was telling about a friend of his and fellow cystic fibrosis patient who caught a fungi infection which he now cannot get rid of anymore, showing how fast a seemingly little infection can change the life of a cystic fibrosis patient for the worse without any kind of warning.”
        “The variance in the extent of the limitations of the disease in different patients, including how the disease differs in its severity, even in patients of the same age.”
        “How positively and calmly Max deals with his illness but has also pointed out that he is lucky, and that other people are much worse off - how much you have to pay attention to little things that you wouldn't have expected as a healthy person.” </p>
    </>],
    implementation: [<> <p>This most important aspect of this meeting was less an insight, but the fact Max helped us to put a face to an abstract idea. Many of our ideas were interesting and adventurous but meeting him put a lot into perspective. </p>
      <p>Our focus shifted to the safety of our creation. When coming up with ideas, we asked ourselves,
        Is this idea a promising or an interesting one?
        Would it be thrilling to create or benefit patients?   </p>
      <p>Due to this, Max had a profound influence on our project from the beginning and is the main reason why we chose Integrated Human Practices and Safety & Security as our special prizes. Only after this discussion did we decide on targeting the lung instead of the pancreas and discarded the idea of a diagnostic approach. He did not only give us important information but most importantly personal investment into our project.  </p></>],
    pictureurl_implementation: "",
    interview: <><QaBox q="How and when were you first diagnosed? " a="When I was about one year old. My mother did not do any screenings or prenatal testing. I was in pain but as an infant you cannot say that, so I screamed a lot. Many doctors shrug that off in small children but after some time a sweat test was done at the children's clinic." />
      <QaBox q="What do you think about diagnosing via sweat tests?" a="I am a clear opponent of diagnosing via sweat tests, especially if it is used to rule out CF and people have atypical CF, because of which they do not get diagnosed because of that." />
      <QaBox q="What symptoms do you have?" a="Before taking modulators, I was underweight and did not feel hunger. I also had no sense of taste. Now, I have a healthy weight and still have respiratory symptoms such as very sticky mucus and digestive issues." />
      <QaBox q="You are taking individual meds, correct? They are individual in respect to the mutation, not the person, right?" a="Yes, and yes, I am. " />
      <QaBox q="What other medications are you taking? " a="Nasal spray, pancreatic enzymes, saline solution for inhalation and pantoprazole, used to reduce stomach acid production.  " />
      <QaBox q="Do you know how exactly they work?" a="Yes, I wrote a report on that during school. In the children's clinic they explained it like this: The CFTR channel is like a door and people with CF don’t have that many doors and some of the doors are broken. The medication makes more doors that function." />
      <QaBox q="What changed when you started taking the modulators? " a="Everything. Most of symptoms are minor now and I have a better lung function and quality of life. I even grew taller." />
      <QaBox q="Did you formerly take other medication?" a="I don’t remember anything like that, but I also always had good medical care.  " />
      <QaBox q="Do you experience any side effects from your medications?" a="At first yes, a lot. Stomach cramps and difficulty breathing for example." />
      <QaBox q="Is diabetes a concern of yours?" a="Yes, it is common. I have to go to a diabetes checkup once a year. That happens together with all the other checkups like sonographies." />
      <QaBox q="Do you know fellow patients that took part in clinical study for gene therapy or at least thought about doing so?" a="I know no one that took part in one but definitely people who would like to do so." />
      <QaBox q="Do you know other patients that would want to use gene therapy?" a="Yes, most definitely." />
      <QaBox q="Since your sweat is different, do you have trouble with your temperature regulation?" a="No and I do not know any patients with an issue like that. But it still is uncomfortable in the summer, because the sweat is thick, and it can smell stronger, too." />
      <QaBox q="How many hours a day are devoted to your illness?" a="Good question, but wrong patient. I am blessed with good health while other people my age may have to be on a ventilator. I currently only have to inhale for 20 minutes every day, take my medication and be conscious about hygiene. I would say 30 minutes a day. " />
      <QaBox q="That means you do not have many limitations due to CF, is that right?" a="Yes. There are many things I am concerned about but often there is not a different way." />
      <QaBox q="What are some of the limitations you do have?" a="Of course, I am still concerned about my health and using public bathrooms for example. And I still do not go swimming in lakes and things like that. But all in all, I feel like I can live a very normal life.  " />
      <QaBox q="One concern is hygiene. Our university for example does not have toilet seats in most bathrooms. Do you think there should be?" a="That does not concern healthy people, who are the majority. But specifically for CF-people? No, there are too few at the university. It would be more hygienic overall, though. A “CF-toilet” would be nice as a form of a disabled bathroom." />
      <QaBox q="How was your childhood as a sick child and how did your parents act with you?  " a="My mother is active in the Muko e.V. and has been for some time. My parents always lead by example about what to do and not to do and dealt with it in a good way. My mother was always very committed and involved in giving me good care. I always knew about my illness but felt it was not that bad, because I received good care and education about my illness." />
      <QaBox q="What is a typical age for a diagnosis in your experience?" a="Somewhere between the pregnancy and one year. It is obvious if the children do not gain weight and there are genetic screenings one can do prenatally or after birth.  " />
      <QaBox q="If a diagnosis is possible during pregnancy, do you know of any treatments during pregnancy?" a="No, I think the youngest age for modulators is 3 years. But people can do genetic testing and counselling before pregnancy." />
      <QaBox q="What does a high-fat diet entail?" a="For me, it was a lot of oil and butter and high-calory drinks.  " />
      <QaBox q="What would happen if you stopped taking your medications?" a="The first thing to happen would be heavy and dry coughing, because the mucus would not be removed properly anymore. Thus, bacteria would not be properly removed from the lungs anymore either and an infection would become more likely. And I would not be able to really process food anymore, so no nutrients, feeling weak and stomach problems.  " />
      <QaBox q="Physical therapy is a part of your treatment – what exactly do you do there?  " a="Breathing exercises and training my lung volume to keep it on the same level. " />
      <QaBox q="Do you have further wished for your therapy?" a="Not really. I am very lucky and am free of heavy symptoms on most days. " />
      <QaBox q="Is that the norm or do you know people who do want new therapies?" a="No, there is a need for new therapies.  " />
      <QaBox q="Are these people with different mutations or worse health? " a="I don’t know, the progression is so individual, and infections can create big changes.  " />
      <QaBox q="A therapy for which organ would benefit most people that have worse health than you do?" a="Probably the lung. The pancreas is important too, but stomach problems are usually less pressing than difficulty in breathing." />
      <QaBox q="You mentioned that doing sport is difficult with CF, why?" a="Hygiene. In the lockers and the showers but also with the equipment." />
      <QaBox q="Do you feel restricted in your free time activities?" a="No, I always had good alternatives. For example, going swimming at an open-air swimming pool instead of a lake.  " />
      <QaBox q="Would you have more freedom when you are better protected from Pseudomonas spcc. and other potential infections?  " a="text" />
      <QaBox q="text" a="Definitely. That is a big increase in the quality of life and that is a win. It also changes the picture people have of the illness. Of course being protected by prevention is good already but effective therapies for infections increase the sense of freedom even more. " />
      <QaBox q="You said you are afraid every time you must go for a swab, why is that? " a="I am afraid of getting an infection. That still could be a death sentence.  " />
      <QaBox q="Are rooms with air conditioning a problem due to the possible germs in the air conditioners?  " a="No, there is usually enough movement. But humidifiers are bad because of the pond water.  " />
      <QaBox q="You mentioned going to the hairdresser is problematic. Could you elaborate? " a="There are many possible sources of ponding water and with that, infections. That and the hygiene aspect in general. I am visited by my hairdresser, and he only uses a specific spray bottle to wet my hair that I keep and dry thoroughly between uses." />
      <QaBox q="Are you the first person in your family that has CF?  " a="Yes. But I suspect my father has a light or atypical form because he has suspicious mucus." />
      <QaBox q="With life expectancies looking better, do many patients want to have biological children?" a="Not all but some. I think some would be interested in a therapy that can be done on the fertilized egg to have a healthy child.  " />
      <QaBox q="Do you know the film “Five feet apart”? If so, what do think about it, is it accurate?  " a="Yes. It does not paint a wrong picture; their progression is possible." />
      <QaBox q="Do you think there has to be more effort concerning diagnostics?" a="Early diagnosis is covered by the screenings." />
      <QaBox q="Since you almost had to sue for your medication, do you know if there are any lawyers specializing in cases like this?  " a="No, I don’t.  " />
      <QaBox q="Are most of the other patients you know in good health like you?" a="No. Another boy my age got a fungal infection and does not have long time left to live.  " />
    </>,
    summary: "",
    months: ""
  },
  {
    title: "Prof. Dr.",
    vorname: "Wolf-Michael",
    nachnname: "Weber",
    job: "Professor ",
    affiliation: "Univesity Münster",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "Feedback Session with Experts",
    interviewtabid: "weber",
    cardtext: "",
    language: "en",
    quote: "x",
    aimofcontact: [<p>The aim of the interview was to gain expert insights on optimizing the delivery of CFTR-mRNA via lung-targeted lipid nanoparticles (LNPs) for cystic fibrosis (CF) treatment.
      Specifically, the goal was to explore potential cell targets, challenges in delivery mechanisms, and technical tools for assessing the effectiveness of mRNA therapies like the Ussing chamber system. </p>],
    insights: [<p>The experts highlighted the potential of targeting ionocytes, given their key role in CFTR expression, but emphasized the difficulty in accessing them due to their basal position in the respiratory epithelium.
      While Prof. Weber found ionocytes to be an intriguing target, Dr. Große-Onnebrink pointed out that there is still limited understanding of their exact role in CF pathology. Both stressed the challenge of penetrating the
      mucus barrier in vivo, particularly when using air-liquid interface cultures, and underscored the importance of optimizing particle size to ensure effective delivery to the deeper regions of the lungs.
      Prof. Weber also emphasized the need to test whether the system can still transfect cells in the presence of mucus. </p>,
    <p>It was suggested to use the Ussing chamber to assess the effectiveness of the delivery system and therapeutic mRNA, though they noted certain challenges with this technique. We also discussed alternatives like organoids,
      which offer only indirect measurements of CFTR function, and patch clamping, which, though more precise, is a more complex and expensive method. Additionally, Prof. Weber recommended exploring chitosan-based delivery
      systems due to their success in his previous work, suggesting they could be a safer alternative to PEG-lipid systems, which had shown issues with cytotoxicity. </p>],
    implementation: [<p>These insights helped refine our iGEM project in several key ways:
      <ul>
        <li>Cell Targeting: We decided to continue exploring ionocytes as a target but acknowledged the technical hurdles involved. We also expanded our focus to include multiple cell types to test different delivery systems. </li>
        <li>Delivery Systems: We began investigating chitosan-based nanoparticles as a safer alternative to PEG-lipid systems. The suggestion to optimize particle size and delivery for inhalation was also integrated into our design. </li>
        <li>Experimental Tools: Based on the discussion, we plan to use an Ussing chamber to measure overall CFTR function in different cell types but will also explore organoid-based approaches for preliminary testing. Additionally, we consulted the medical faculty on the possibility of using patch clamping for more detailed measurements of successful transfection and restored CFTR function. </li>
      </ul>,
    </p>],
    summary: "",
    months: ""
  },
  {
    vorname: "Exploring new ideas",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    affiliation: "",
    heading: "Further brainstorming on approaches",
    interviewtabid: "brainstorming",
    cardtext: "",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Michaela",
    nachnname: "Bienert",
    job: " Scientific Sales Representative for Cell Culture Products",
    affiliation: "Stemcell",
    pictureurl: pics['placeholder'],
    tag: "Industry",
    heading: "Determining the optimal cell media for experimentation",
    interviewtabid: "michaela",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    vorname: "Looking for expertise",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    heading: "Identifying key experts in cystic fibrosis and prime editing",
    interviewtabid: "experts",
    cardtext: "",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: ""
  },
  {
    vorname: "Documenting progress",
    nachnname: "",
    pictureurl: pics['placeholder'],
    tag: "Other",
    heading: "Tracking progress in expert search and idea development",
    interviewtabid: "progress",
    cardtext: "",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    type: "meta",
    summary: "",
    months: ""
  },
  {
    vorname: "Jan-Phillipp",
    nachnname: "Gerhards",
    job: "Student",
    affiliation: "Intern at Harvard/ Boston Childrens Hospital",
    pictureurl: "https://static.igem.wiki/teams/5247/photos/hp/hp-jpgerhards-potrats.webp",
    tag: "Academia",
    heading: "Discussion on optimizing our pegRNA Design to improve precision in prime editing",
    interviewtabid: "JPpegRNA",
    cardtext: "",
    language: "de",
    quoteNachname: "Lenger, Teammember",
    quoteVorname: "Malte",
    quote: "The interview proved invaluable in gaining an initial understanding of the principles of pegRNA design and optimisation, particularly in the context of silent edits.",
    aimofcontact: "The aim of the contact was to engage in a discussion about prime editing and pegRNAs, as the Jan-Phillip Gerhards had used these technologies in his internship. We sought to exchange ideas, gather insights, and explore potential improvements or strategies for our project, leveraging his experience with prime editing tools. His practical knowledge in this field was very valuable for refining our approach and ensuring we were aligned with the latest advancements and methodologies in prime editing. ",
    insights: "During our discussion we gained valuable insights that had a significant impact on our project. One of the most important findings was the effectiveness of silent edits, which will enable us to make our PrimeGuide safer. Silent edits changes the sequence of bases in the DNA in such a way that the resulting protein remains unchanged, because the genetic code is redundant. This means that different codons can code for the same amino acid. By making silent edits in addition to correcting the CFTR gene, we can prevent the pegRNA from rebinding.  We have also learned that the length of the primer binding site (PBS) plays a crucial role in determining optimal results and that it is recommended to keep the PBS temperature close to 37°C. Specifically, PBS lengths of 17nt (38.3°C) and 16nt (36.4°C) were found to be ideal options. For our planned set of 12 samples, it was recommended to use three different PBS lengths (differing by +/- 1nt from that close to 37°C) in combination with four RTTs to achieve the best result. Another important finding was the use of non-annotated regions with overhangs for cloning, which could give better results in our experiments. However, we also encountered concerns that circRNA, a covalently closed circular RNA molecule, might be sterically hindered by Cas9, which we need to investigate further. When discussing cloning overhangs, we learned that a base-pair length close to 60°C is optimal. However, the use of a 15nt PBS was not recommended as it has a lower temperature range which could affect performance. Although we still need to confirm the oligonucleotide delivery time, these findings will help us to refine our cloning strategy, optimise PBS selection and improve our overall approach to primer editing, especially in terms of the pegRNA design.",
    implementation: "We incorporated the lessons learned from our discussions on prime editing and silent editing directly into our project by refining our approach to gene editing. Based on feedback about the optimal length of primer binding sequences (PBS) and RTTs, we adjusted the design of our pegRNAs to ensure greater precision and efficiency in our experiments. In particular, we learned that using PBS lengths close to 37°C melting temperatures (e.g. 16-17 nucleotides) increased stability, which led us to fine-tune these sequences for improved editing results. The concept of silent editing became an integral part of our safety strategy, allowing us to make changes to the DNA more precise. We also revised our cloning strategies by considering the appropriate overhang length, targeting a base pair length near the melting temperature of 60°C to improve cloning efficiency. We also reassessed the practicality of ordering shorter PBS sequences, concluding that lengths shorter than 15 nt were less advantageous due to reduced efficiency. By integrating these findings, we optimised our experimental workflow and made informed decisions about the tools and methods for our prime editing experiments. ",
    summary: "",
    months: ""
  },
  {
    vorname: "Katrin",
    nachnname: "Westhoff",
    job: "Physiotherapist",
    affiliation: "Independent",
    pictureurl: pics['westhoff'],
    tag: "Medical Professional",
    heading: "Interview with a specialized physiotherapist regarding breathing therapy for cystic fibrosis patients",
    interviewtabid: "westhoffinv",
    cardtext: "",
    language: "de",
    quote: "The more we know, the more opportunities we have.",
    aimofcontact: "The objective of the contact was to gain in-depth insights into the treatment and care of children with cystic fibrosis. The therapist's expertise was intended to help develop a better understanding of the challenges and necessary measures in the treatment of this chronic disease. In addition, the aim was to ascertain how the therapy is implemented in everyday life and which specific approaches and methods are particularly effective.",
    insights: "The interview yielded valuable insights into the regular implementation of the therapy, the use of aids and the adaptation of exercises to the individual needs of the patients. It was notable that the therapy has improved considerably thanks to better medication and adapted exercises, with a concomitant increase in life expectancy for children affected by cystic fibrosis. Of particular interest was the emphasis on the importance of sport and exercise, which should not only be therapeutically effective, but also increase quality of life. ",
    implementation: "The following statement by Katrin Westhoff had a particularly profound impact on our project: 'The more we know, the more opportunities we have.' We learned from the interview that the current medication is already helping many patients to a huge extent, but that there is still a significant opportunity for improvement. After all, successful gene therapy would markedly enhance the quality of life for those affected. The findings of this project will be disseminated to the relevant researchers in order to facilitate the rapid improvement of the quality of life of all cystic fibrosis patients, regardless of their mutation. ",
    pictureurl_interview: "https://static.igem.wiki/teams/5247/photos/hp/katrin-westhoff-zoom.webp",
    summary: "",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Cristian-Gabriel",
    nachnname: "Olariu",
    job: "pediatrician",
    affiliation: "OWL University Hospital",
    pictureurl: pics['olariu'],
    tag: "Medical Professional",
    heading: "Discussion with a pediatrician and his former patient about treatment challenges and perspectives",
    interviewtabid: "olariu",
    cardtext: "",
    language: "de",
    quote: "For most families, it’s a shock. Cystic fibrosis still has a strong association with being a life-threatening disease, despite the fact that we now have good treatments, and many patients can live healthy lives. The diagnosis puts a huge psychological strain on the family, especially when dealing with very young children.",
    aimofcontact: "To gain a deeper insight into the path to diagnosis, we invited pediatrician Dr. Cristian-Gabriel Olariu from the University Department of Pediatrics and Adolescent Medicine to share his experiences with cystic fibrosis (CF) patients with us. We interviewed him because of his expertise in the effects of diagnosis on the patient and the family members, but also on daily life. Additionally, we want to close the gap and create a bridge between academic research and clinical applications. Therefore, Dr. Olariu gave insights about the clinical perspectives on CF patients.",
    insights: [<p>We invited Max, our CF patient contact, to join Dr. Olariu in discussing the intersection of academic research, clinical application, and patient needs. Through our connection with CF Vests Worldwide (link zu deren Website? https://www.cfvww.org), an organization dedicated to providing life-saving therapy vests to cystic fibrosis patients globally, we gained insights into the challenges faced by CF patients, particularly in regions like Thailand, where access to advanced treatments and medical devices is limited. The conversation highlighted the critical role of early diagnosis and intervention, as well as the quality-of-life challenges many patients endure due to conventional treatments that may not be effective for everyone. Innovative approaches, such as our SORT LNP (lipid nanoparticle) delivery system, present promising alternatives for CF therapy. This system, which allows for RNA encapsulation and administration via dry spray inhalation, could revolutionize treatment by targeting lung cells more effectively, particularly in resource-limited settings. Dr. Olariu underscored the need for psychological support and coordinated care for CF patients, emphasizing that novel therapies like LNP-based gene treatments have the potential to improve treatment efficacy and accessibility, ultimately reducing the lifelong burden of care for patients and their families. </p>,
    <ol>
      <li>Diagnosis:</li>
      <li>Detection through newborn screening.</li>
      <li>Further tests (including sweat tests) are conducted if results are abnormal.</li>
    </ol>,

    <ol>
      <li>Early Treatment:</li>
      <li>Begins with inhalations, physiotherapy, and medications.</li>
      <li>Aim: Prevention of severe complications and organ protection.</li>
    </ol>,

    <ol>
      <li>Challenges:</li>
      <li>Some patients do not respond well to conventional treatments.</li>
      <li>Significantly impacts quality of life.</li>
    </ol>,

    <ol>
      <li>Family Burden:</li>
      <li>Medical challenges create a significant burden.</li>
      <li>Psychological stress due to lifelong treatment.</li>
    </ol>,

    <ol>
      <li>Importance of Support: </li>
      <li>Psychological support is crucial.</li>
      <li>A well-functioning treatment team is essential.</li>
    </ol>,
    <p>We have jointly weighed up the extent to which an early diagnosis is always an advantage, as some parents perceive an early diagnosis as an additional burden and would prefer to experience the first years of their child's life without constant medical intervention. Especially when there are cases in which patients only show a clear clinical picture at an advanced age. The psychological burden also lies with the children, who often experience medical trauma because they are involved in such intensive medical care from birth. Additionally, the treatment of cystic fibrosis is very expensive, and the costs are covered by health insurance companies to varying degrees. In some countries, such as the USA, Ukraine or Developing countries, many families cannot afford the necessary treatments. Dr Olariu drew our attention to another problem in the treatment of cystic fibrosis. Infections, especially with bacteria such as Pseudomonas spcc., are difficult to treat and often lead to long hospital stays. Max, our patients’ representative, who knows Dr. Olariu through his treatment, talked about his infections with Pseudomonas spcc., illustrating the reality of an invisible danger that determines a patient's everyday life. Strict hygiene measures are required to prevent infections, such as wearing face masks in hospital and careful handling of potential sources of infection. The clinics where cystic fibrosis patients are treated work closely with a multidisciplinary team of doctors, psychologists, physiotherapists and nutritionists to ensure that patients receive holistic care. At the same time, research is constantly being carried out and new therapeutic approaches developed, such as the use of nanoparticles to improve drug delivery. Former patients are also involved in research and provide valuable insights and advances. </p>,
    <ol>
      <li>Pros of Early Diagnosis and Treatment</li> </ol>,
    <ol>
      <li>Timely Intervention: Prevents severe organ damage and improves long-term outcomes.</li>
      <li>Holistic Care: Involves a multidisciplinary team for comprehensive patient support.</li>
      <li>Access to Innovations: Allows patients to benefit from advancements like nanoparticle drug delivery.</li>
      <li>Family Support: Provides education and resources for effective management from the start.</li>
    </ol>,

    <ol>
      <li>Cons of Early Diagnosis and Treatment</li></ol>,
    <ol>
      <li>Psychological Burden: May cause stress for parents and children due to constant medical interventions.</li>
      <li>Cost Implications: Treatments can be expensive, with varying insurance coverage, leaving many families unable to afford care.</li>
      <li>Infection Risks: Patients still face risks from infections like Pseudomonas spp., leading to potential hospitalizations.</li>
      <li>Over-medicalization: Continuous focus on treatment can overwhelm families, affecting the quality of early childhood experiences.</li>
    </ol>,
    ],
    implementation: "In summary, our project greatly benefited from the conversation with Dr. Olariu. His insights into the complexities of cystic fibrosis treatment, particularly the significance of early diagnosis, were invaluable. Max’s personal experiences added a crucial human perspective, illustrating the medical and psychological challenges he faces, including infections with Pseudomonas spp. Dr. Olariu emphasized the importance of a multidisciplinary approach, involving not just medical professionals but also psychologists, physiotherapists, and nutritionists for holistic care. This discussion helped us appreciate the balance between timely interventions and the emotional burden on patients and their families, guiding us to develop a more empathetic understanding of living with cystic fibrosis. ",
    interview: <>
      <QaBox q="Could you please tell us about the journey that parents go through with their CF-sick children from the first visit to diagnosis and treatment?" a="Since 2016, cystic fibrosis (CF) diagnosis has been part of newborn screening. This means that we receive many children right after birth whose screening results were abnormal. These children are then sent to us for further clarification. Not every child with an abnormal screening result is sick, so we perform a sweat test, and about one-third of the children are diagnosed with the disease. The advantage of early diagnosis is that we can intervene and start treatment early to prevent organ damage. However, there are also rare mutations where the course of the disease is difficult to predict." />
      <QaBox q="What are the pros and cons of newborn screening for cystic fibrosis?" a="From a medical point of view, it’s beneficial that we can catch many of these cases early, allowing us to act swiftly. There are even medications for small babies, and early intervention can protect organs, preventing conditions that would require transplants later on. On the downside, because of the wide variety of genetic mutations, some cases we identify may not show significant symptoms until adulthood. This creates a dilemma, as we can’t predict how their condition will progress, but we still start treatments early, which can be stressful for families." />
      <QaBox q="Can you give us an example of how this stress impacts families?" a="Yes, I’ve been caring for a patient from birth who is now five years old and doing very well. However, from the beginning, she had to undergo physiotherapy, regular check-ups, and blood tests, even though she hasn’t shown any major symptoms. Her mother once told me she wasn't sure if she would make the same decision again, as the early intervention caused a lot of stress. She wondered if she might have enjoyed the first year of her child’s life more if things had been more relaxed. Now, at age five, nothing significant has changed in her condition, and they’ve decided against starting modulator therapy for the time being." />
      <QaBox q="How do families typically react when a CF diagnosis is confirmed?" a="For most families, it’s a shock. Cystic fibrosis still has a strong association with being a life-threatening disease, despite the fact that we now have good treatments and many patients can live healthy lives. The diagnosis puts a huge psychological strain on the family, especially when dealing with very young children. The most important factor in managing this, aside from medical treatments, is the support from the medical team. It’s critical to have a team that works well together, not just a single doctor calling all the shots. Families often need much more psychological and nutritional support early on than medical intervention, and this is where having a multidisciplinary team becomes essential." />
      <QaBox q="What is the process for diagnosing and treating older patients who haven’t been through newborn screening?" a="Older patients who come to us with complaints may not have undergone newborn screening, so they are diagnosed based on their symptoms. These complaints can range from mild to severe and are often non-specific, like chronic cough or failure to thrive. When the cause of these symptoms isn’t immediately clear, we do a sweat test. Once diagnosed, we can start treatment, which often involves working with a psychologist to help the family process the news." />
      <QaBox q="How do you support families during the initial shock of diagnosis?" a="When the diagnosis is particularly difficult for families to process, we sometimes have the patients stay in the hospital for up to a week. This gives us time to meet with them daily, answer questions, and provide guidance. During the first consultation, families often fall into a state of shock, and no matter how carefully the doctor explains things, it’s hard for them to absorb all the information. Meeting with them again over the following days helps, and we have specialists in hygiene, physiotherapy, and social counseling on the team to offer holistic support." />
      <QaBox q="What happens if a child gets infected with Pseudomonas or another bacterial culture in the lungs?" a="Pseudomonas is one of the most feared infections for CF patients. It’s a common environmental bacterium that is difficult for CF patients to clear from their lungs. Once we detect it, we treat the patient with specific antibiotics, often through intravenous delivery over two weeks in the hospital. After the initial treatment, patients may continue with inhaled antibiotics for several months to prevent further infection. It’s a very intensive process, taking a lot of time and energy, and even though we may get rid of the infection a few times, eventually the germ can become resistant and stay in the body." />
      <QaBox q="Are there any preventative measures to avoid Pseudomonas infection?" a="Yes, there are hygiene measures. For example, CF patients always wear masks in the hospital to avoid infection from other patients. But it’s difficult to avoid Pseudomonas entirely since it’s found in stagnant water and other places in the environment. We advise patients to be cautious with water sources like sinks or ponds. However, we need to balance strict hygiene with quality of life, especially for children, as being overly strict can lead to obsessive-compulsive behaviors without necessarily reducing the risk of infection." />
      <QaBox q="Do some families resist the medical advice on preventing infections?" a="On an emotional level, I feel that families who take calculated risks to improve their quality of life tend to cope better. Overprotection can lead to greater psychological stress. However, I don't have enough experience to say for sure whether those who don’t protect themselves as strictly get infected earlier or suffer worse outcomes. It’s also worth noting that new therapies are now available that help reduce infection risks, allowing for a bit more freedom, especially for children." />
      <QaBox q="How often do patients need to be tested for infections like Pseudomonas?" a="The official guideline is every two months, but realistically we aim for every 3-4 months. Regular testing is important because Pseudomonas can be present without symptoms. If too much time passes before detection, it becomes harder to remove the infection." />
      <QaBox q="How do you manage chronically infected patients?" a="Patients who are chronically infected with Pseudomonas don't stay in the hospital indefinitely. They usually remain at home, inhaling antibiotics daily and taking physiotherapy to help clear mucus from their lungs. Intravenous antibiotic therapy is reserved for more severe cases or during clinical deterioration." />
      <QaBox q="Are chronically infected patients allowed to visit your practice?" a="Yes, chronically infected patients are allowed to visit the practice. We try to schedule them at different times to avoid contact between infected and non-infected patients, and we often use separate rooms to minimize risk." />
      <QaBox q="How often do children and adults need to have lung function tests?" a="You can’t conduct a good lung function test until the child is around five years old. After that, it becomes part of the routine check-up because it’s non-invasive and provides a good indicator of lung health. We see children every three months, and I believe the protocol is the same for adults." />
      <QaBox q="What do you think about support groups or health retreats for CF patients?" a="Support groups are extremely important. Although we are a good medical team, advice from peers often resonates more with patients. We’ve organized two parents' evenings recently, where parents can exchange experiences and support each other. Unfortunately, we can’t invite the children themselves due to the risk of infection, but in rehabilitation settings, they can meet in germ-specific groups and benefit from shared experiences." />
      <QaBox q="Is there a risk of antibiotic resistance with repeated treatments?" a="Yes, resistance is a concern, especially with repeated antibiotic treatments. However, there’s often a discrepancy between what we see in lab tests and the clinical outcomes. Even if a germ shows resistance on paper, many patients still respond well to treatment. We base our decisions more on clinical outcomes than lab results, changing antibiotics only if the patient’s condition doesn’t improve." />
      <QaBox q="Are there any side effects to the medications?" a="Yes, all medications have potential side effects, though many of them are minor, like rashes or stomachaches. One serious side effect of some antibiotics is hearing damage, which can lead to lifelong hearing loss. This is why we closely monitor patients in the hospital when starting treatments. The newer therapies, like modulators, can cause liver stress, so we regularly check liver enzymes in the blood. However, severe side effects are rare, and the drugs are generally well tolerated." />
    </>,
    pictureurl_aim: "https://static.igem.wiki/teams/5247/photos/hp/interview-olariu.svg",
    pictureurl_interview: "https://static.igem.wiki/teams/5247/photos/hp/olario-abbildung1.svg",
    summary: "",
    months: ""
  },
  {
    vorname: "Mattijs",
    nachnname: "Bulcaen",
    job: "PhD Researcher at Laboratory for Molecular Virology & Gene Therapy",
    affiliation: "KU Leuven",
    pictureurl: pics['mattijs'],
    tag: "Academia",
    heading: "Discussion with a Prime Editing Expert on Similar Approaches for Different Mutations",
    interviewtabid: "mattijsinv",
    cardtext: "",
    language: "en",
    quote: "[…] Prime Editing system is more complex than the canonical CRISPR systems, with more variables that can influence success or failure.",
    aimofcontact: [<p>Shortly after we decided to use prime editing as the gene editing method for our cystic fibrosis therapy, Mattijs Bulcaen from the Laboratory of Molecular Virology and Gene Therapy at KU Leuven and his colleagues published a paper directly related to our research <TabScrollLink tab="mattijsinv" scrollId="desc-1" num="1" />. In contrast to our approach, Bulcaen et al. 2024 targeted other, less common but drug-refractory CFTR-specific mutations (L227R- and N1303K).  </p>],
    insights: "The interview with Mattijs was valuable for us in a lot of ways. At that point in the project we were starting to design the components of our prime editor, but we were lacking a broader overview over the state of the field. Mattijs gave us this insight, mentioning techniques like PE3b systems, dsgRNAs and a talk given by David Liu,[Link] the principal investigator behind prime editing that helped us to consider further novel advancements in in Prime Editing and include them into our project. He discussed with us the difficulties that might await us when targeting the CFTR F508del deletion and mentioned that insertions of all the edits possible with prime editing are the hardest to make, the recognition of edits in the region might attract mismatch repair systems and the chromatin organization might negatively impact prime editing efficiency. Also, we learned a lot about how to design our pegRNAs, with important inputs being the 3’ stem loop motif trevopreQ1 used by Mattijs in his publication and the suggestion to use prediction tools to evaluate sgRNA spacer cutting efficiency. We reviewed our approach of testing pegRNAs using the PEAR reporter system and Mattjis recommended to use HEK cell lines for screening because of their easy handling and naturally impaired mismatch repair system. ",
    implementation: "The inputs given by Mattijs directly impacted our design choices for multiple parts of the project. For the pegRNA design, we decided to use the same 3’ motif as Mattijs had used and also, like he suggested, checked our spacer candidates for predicted cleavage efficiency. Also we used HEK cells for screening our pegRNAs. We looked further into PE systems that influence cellular mismatch repair (such as PE4) and tried to include these into our design. ",
    interview: <>
      <QaBox q="You mentioned that it was quite challenging to target the F508del mutation. Could you provide more detailed reasons for why this is the case or explain why this mutation is particularly difficult to target compared to others?" a="Yes, that's the million-dollar question. First of all, let me clarify: our group has never directly worked on that mutation because we immediately focused on the drug-refractory mutations, such as nonsense mutations where the protein is not formed, indel mutations, or severe missense mutations that do not respond to modulator therapies. Of course, we know several groups in the field who either work on gene editing or focus on cystic fibrosis (CF). We've heard from some of them who attempted to target the F508del mutation. For example, some collaborators really tried to design different guides but were unable to find anything above the detection limit. F508del is probably one of the most logical mutations to try to correct, not just for CF but for the entire gene-editing field. If you look at the frequencies of mutations that cause genetic diseases, the F508del mutation is by far the most common deletion mutation causing a severe disease. This is because CF, along with sickle cell disease, is one of the most common deadly inherited diseases, and it's overrepresented within CF. So, it makes sense that they would have been trying to target it from the beginning. Interestingly, if you read the Prime Editing paper by Anzalone, F508del is mentioned in the introduction in connection with cystic fibrosis. So, it's somewhat surprising that after all this time—it's been almost five years now—they haven't published or released anything on F508del. However, last weekend, there was an online seminar where David Liu gave a talk, and he showed some unpublished data indicating that they managed to achieve quite good Prime Editing efficiency on F508del. It's worth noting that David Liu rarely presents unpublished data unless the publication is either accepted or very close to acceptance. So, we all kind of expect that the paper will be published soon, perhaps within the next week or at least within a month. From what I saw, it appears they leveraged many of the approaches available today to enhance Prime Editing. Now, regarding your question about why this mutation is so difficult to target with Prime Editing, I can't provide an exact answer. However, I can list some potential difficulties associated with the mutation, and it’s likely that F508del is challenging for several of these reasons. For instance, it could be related to the genomic region itself. Writing insertions can be more difficult; the easiest edits are single-point mutations, followed by deletions, and the most challenging are insertions. This difficulty arises because it involves writing a third strand and then relying on DNA damage repair mechanisms to fix it. It could also be that the region around the F508del mutation is challenging due to flap equilibration or that it attracts pathways such as mismatch repair that negatively impact Prime Editing. Additionally, the chromatin organization around that region could play a role. Over the past year, we’ve gathered clues that chromatin organization significantly affects Prime Editing capability, while this is much less of an issue for Cas9 and base editors. Studying this is not straightforward; you would need to conduct experiments like ATAC-seq to determine the chromatin organization around the mutation and how it might interfere. I also noticed on a slide that dsgRNAs were mentioned, though David Liu didn't discuss them in his talk. After looking them up online, I found that this technique, published a few years ago by other researchers, is specifically designed to open up chromatin. It seems they use different guides, without the three-prime extension, to open up the chromatin, which could be one way to overcome the limitations in Prime Editing efficiency. There could be other factors as well, and it’s often difficult to predict what will work and what won't. We have prediction tools for Prime Editing guides that work to some extent, but they are not as effective as the prediction tools available for regular CRISPR guide RNAs. This suggests that the Prime Editing system is more complex than the canonical CRISPR systems, with more variables that can influence success or failure. I hope this answers your question somewhat." />
      <QaBox q="Perhaps we could quickly discuss which part of the prime editing complex you think plays the most significant role in making insertions much more challenging compared to deletions. Is it the reverse transcriptase or the RNA?" a="I don't think it's primarily the reverse transcriptase that's the issue. People have shown that longer insertions are definitely possible. I believe the challenge lies in the process when your cell has to repair the new DNA strand, which is generated and exists as a three-stranded intermediate. We don’t directly intervene in this process; it entirely depends on the cell and the DNA damage repair pathways active in those cells. Through expression of dominant negative DNA damage repair effectors, or by nicking the non-edited strand, the outcome can be steered to some extent. When you perform an insertion, the new strand must hybridize with the bottom strand, which remains intact. This creates a small loop that needs to be incorporated. At this point, the cell faces two options: it can either revert to the original state or incorporate the edit you’re trying to introduce. In certain circumstances, perhaps due to how the new DNA strand folds or the sequence context of the region of interest, the cell might heavily favor reverting to the original state, resulting in the absence of the intended edit. This process is extremely difficult to predict, but there are several indications pointing in this direction. For example, in the case of point mutations, it has been shown that it’s easier to convert a C to a G rather than the reverse, simply due to how these mismatches are recognized by the DNA damage repair mechanisms. This area is very complex, and I don’t think anyone fully understands it yet. It’s also difficult to study. I don't believe the rate of reverse transcription is the limiting factor here, although it could play a role for long or structured pegRNAs. You might have already come across this, but the PE6 generation of Prime Editors, which were released about half a year ago, involve engineered or evolved reverse transcriptases that are more processive and can more easily synthesize longer transcripts. Another factor that could play a role is the secondary structure of the guide RNA. Each prime editing guide RNA faces a common problem: it has a spacer that binds the bottom strand and a three-prime extension that binds the top strand. Since these two parts of the RNA bind complementary strands, they are also complementary to each other, meaning every prime editing guide has some tendency to bind itself. If the Gibbs free energy is too high, the guide RNA may fold in on itself, preventing it from binding to the prime editor, which then inhibits prime editing. Additionally, the three-prime extension itself can fold independently. I haven’t specifically examined this for the F508del guides, but it is something that can be predicted. There are tools available that can predict the secondary structure of an RNA sequence, and if there’s a significant hairpin structure, it might mean the three-prime extension remains closed, preventing the reverse transcriptase from using it as a template. The PE6 prime editors have been engineered to be more effective in such scenarios, being less affected by secondary structures and better able to read through them." />
      <QaBox q="What would be the application? Would you administer the heat shock in vivo, or...?" a="I believe they used it to engineer zebrafish embryos or something along those lines. It’s quite specific, of course. If you plan to deliver your guide RNA through a viral vector or similar method for human therapy, the application would differ significantly. You obviously can't administer a heat shock to humans, so it really depends on the context of your application." />
      <QaBox q="Given the time constraints, let's move on to the next question. Due to our limited resources, we are targeting a PE2 system, and we'd like to ask if you see any chances of success with this system. If so, how high do you think the chances of success are?" a="PE2 can work, but it really depends on your application and the methods you have to assess the editing efficiency. If you can use NGS (Next-Generation Sequencing) for everything, you'll be able to detect edits even with PE2 systems. However, I would generally expect the efficiency to be low. Whenever possible, I would always recommend trying the PE3 system. Could you share what your specific application is, or is that confidential?" />
      <QaBox q="So our goal is to eventually use it in vivo, but for now, we're focusing on trying to correct the mutation first in regular cell cultures and then later in primary cells." a="Is your focus specifically on the F508del mutation? If so, we could potentially help you get you started, as we already have constructs and cells with that mutation. We would need to discuss the financial aspects, but we might be able to assist. However, are you fully committed to targeting F508, or are you also considering other diseases or mutations?" />
      <QaBox q="The timeframe of the project, combined with the fact that we’re all studying on the side, limits us to a certain scope. Since this is our first time tackling a project like this, it makes sense to stick to something more manageable. So, we're somewhat committed to focusing on F508 due to these constraints." a="That's understandable. It can be really tough to juggle a project like this along with exams and studies, especially if you're also involved in competitions. But it's definitely worth the effort, even if you don't achieve huge results right away. The experience and learning, as well as the connections you make, are incredibly valuable. I'm a big supporter of such" />
      <QaBox q="We have one patient who is willing to provide us with cells, but we don't have them yet." a="It sounds like you're aware of the challenges, and I don't want to discourage you, but just to be realistic, working with primary cells and getting everything ready could be tricky, especially considering the competition is in October. Experiments in human cells can take time, especially if you need to do multiple iterations or clone constructs—it could easily take a week or more per experiment." />
      <QaBox q="Regarding the cells we have, as mentioned in our paper, we screened all our guides on HEK cells with an integrated copy of the CFTR cDNA. HEK cells are easy to work with, but they don't naturally express CFTR, even though the gene is present in their genome. So, we introduced the mutation of interest into these cells, making it easier to screen." a="I'm not entirely sure if we can send over the cells due to ethical regulations, which can be complex and time-consuming to navigate. However, there's an alternative approach that might help you. Early on, we found that it's actually quite easy to screen guides using what we call a 'transient target.' In this method, you would transfect all your prime editing plasmids into HEK cells, along with a plasmid containing the CFTR cDNA with the mutation of interest." />
      <QaBox q="While this approach isn’t as physiological as editing the chromosome directly, our side-by-side comparisons showed almost equal efficiencies between transient and chromosomal targets. It's much easier and faster than working with patient-derived cells. I can definitely send you the plasmid, which would save you a lot of time and effort. This method is much simpler and could be a practical solution for your project." a="Our initial plan is to work with a reporter plasmid that expresses eGFP, where we've removed a splice site, until we have patient cells or cell lines with CFTR mutations. This will allow us to screen easily without needing to sequence everything. Do you maybe have any suggestions or advice on this approach?" />
      <QaBox q="Is that the PEAR system?" a="No, it’s a different one, but we also have a similar system. The advantage of this approach is that you can very easily see if it works, and it’s very sensitive—much easier than extracting and sequencing DNA. The downside, however, is that… actually, I’m not familiar with the 'flu PEAR system.'" />
      <QaBox q="Actually, we use the exact same system in our lab. It’s very useful for optimizing delivery strategies because it’s easy to see results. The downside, of course, is that the guides you’re using for that system aren’t specific to the F508del mutation, right? So, these are scientific trade-offs. You could, for example, design a reporter that uses your F508del guide and also results in fluorescence, but you would need to design the reporter first. It’s challenging to prove that it works because you might not have a perfect guide for F508del." a="It really depends on what you want to achieve. If your goal is to first check if you can successfully perform prime editing, then using the reporter is definitely a good first step." />
      <QaBox q="We will edit the plasmid, specifically the vector, so that we have almost the same pegRNA. The only difference will be downstream, behind the edit." a="Is this approach based on a paper from the Netherlands, or is it something you came up with yourself?" />
      <QaBox q="Based on a paper." a="Yeah, that sounds like a very good way to start. Do you already have the reporter plasmid ready?" />
      <QaBox q="Yeah, we bought the reporter, and now we’re making the necessary edits so we can use it." a="Okay, so do you also already have guides targeting F508 right now?" />
      <QaBox q="We’ve designed some guides, but we haven’t tested them yet. That’s one of our next steps. So, at the moment, we’re just in the design phase, or we have already designed them, and..." a="Yeah, okay, cool. Good luck with that! And I suppose you’re starting off with HEK cells as well, right?" />
      <QaBox q="We have HEK and HeLa cells, but we haven't decided yet which ones we'll use." a="I would start off in HEK cells because, by total accident or coincidence, they are much easier to achieve prime editing in. This is because the MLH1 gene, which negatively impacts prime editing outcomes, is naturally disabled in these cells—they don't produce the MLH1 protein. Of all cell lines available, HEK cells are the easiest to achieve editing with, so I would definitely recommend starting there." />
      <QaBox q="In terms of transfection, HEK cells are also very easily transfected. If I can offer another piece of advice, always include GFP controls—plasmids that simply express GFP without requiring editing—and use them to determine your transfection efficiency. It's crucial to have a very high transfection efficiency because you'll be working with a three-component system: your reporter, your prime editor, and your guides. All three plasmids need to be present in the same cell for the editing to occur, so you should aim for at least 70% transfection efficiency, preferably 80% or higher." a="I don't know what transfection method you're planning to use, but we've always used Lipofectamine 3000. It’s expensive, but it works very well. However, if you're looking for more cost-effective options, we recently discovered two other transfection reagents, Jet Optimus and Jet Prime, which are much cheaper and also work quite well. That said, I would advise against starting with any of the cheaper transfection reagents; you really need to aim for high transfection efficiency." />
      <QaBox q="Always make sure to measure and report transfection efficiency for every experiment because if it's low, the experiment might not yield useful results. If you have the funds or resources, I would also recommend designing P3 or even P3b guides, as they might offer better efficiency." a="When it comes to designing P3b guides, if you're primarily focused on P2 right now, there are some specific considerations to keep in mind. I'll provide you with a site that can help with this, and I'll give you the link in just a moment." />
      <QaBox q="So, it's very advisable to check the Doench score. Do you know what it is?" a="No, not really." />
      <QaBox q="There are papers by John Doench, an American researcher, from quite a while ago that, in my opinion, are some of the best around. He developed a comprehensive scoring matrix specifically for regular Cas9 that can evaluate the quality of the spacer in your guide RNA. This is important because Cas9 tends to prefer certain sequences over others. For instance, a good spacer should have an appropriate GC content and should avoid hairpins that might cause it to fold in on itself, which would prevent it from functioning properly. You can use this matrix to give a score for the quality of a guide RNA. I’m going to pull up an example here. The site from Synthego, a commercial provider of CRISPR reagents, allows you to check the quality of your guide. When you validate it, the site gives a score based on various factors, including off-target effects, although that might not be your primary concern at the moment. If you hover over a specific area, it will show you the Doench Score, which is crucial. Ideally, you want a guide with a good Doench Score. A good score starts at around 0.4, indicated by a green check mark for good efficiency. If the score is very low, it means that the guide likely has low CRISPR-Cas9 activity and may not be very efficient. When designing prime editing guides, RNA, we always check the spacer for a good Doench Score. If we are designing nicking guides for a PE3 or PE3b strategy, we also ensure that they have a good score. This is one of the easiest tools to check for that. Whenever possible, try using PE3. In some cases, PE3 performs better than PE2, though not always. PE3b might not always work either, but for many mutations, we have seen significant increases in editing efficiency by including the PE3 guide." a="Okay, yeah, that was quite clear from your results; the diagram illustrated that very well." />
      <QaBox q="Are there more off-target effects when using PE3 since you have to make another cut?" a="If you decide to use PE3, it's important to be aware that while it's not exactly an off-target issue, there is a risk of an undesired on-target outcome. The concern with regular PE3 is that both strands of DNA can be nicked simultaneously, which can lead to a staggered double-strand break. This can result in the formation of indels (insertions or deletions). In your case, this means that if the region around the F508del mutation is broken, the prime editor might not be able to repair it properly, leading to additional base pairs being removed or added, and thus, the sequence might be altered in an unintended way. The risk of on-target indels is definitely higher with PE3 compared to PE2. However, this risk is reduced when using PE3b, which employs sequential nicking. The PE3b nicking guides are designed to recognize the wild-type sequence, and they can only nick the opposite strand if the correction has already been made on the top strand. This sequential action helps to avoid the generation of indels. Introducing a second guide into the system also brings the possibility of off-target editing by that guide however, since only a Cas9 nickase is used, off-target indels should be limited." />
      <QaBox q="Yes, okay, thank you. Do you have time left, or are we out of time?" a="It's fine." />
      <QaBox q="We have more or less one last question. If it’s not possible, that’s completely fine. We just wanted to ask if you could possibly forward the contact details for the Ussing chamber setup in Paris that you mentioned in your email. Would that be possible?" a="You can certainly try to contact them, but I actually know that there are quite good labs in Germany that work on similar things." />
      <QaBox q="One major drawback for you might be the time it takes to differentiate cells. If you harvest stem cells or basal cells from patients, they will have the CFTR gene, but they don’t express it immediately. It takes about four weeks for them to differentiate and start producing the CFTR protein. Without this differentiation, you can't measure the currents, which could slow you down significantly. I'm not sure if you have that kind of time." a="If I can give you one piece of advice: it’s less physiological, but it’s still an accepted assay—try it on organoids. We could actually perform both assays here. If you find guides that work really well, we could consider doing those tests here. Someone could come over, or we could do the experiments if they’re not too expensive and have a good chance of working. I think we wouldn’t mind adding the F508del mutation to our list of editable mutations." />
      <QaBox q="There’s also the possibility that if the paper from the Liu Lab is published within the next month, you could just use the guide they provide, and you’d have a guide that is known to work." a="Yeah, so I think if our guides don’t work as well as we hope, this could be an opportunity. We still want to explore optimization of the prime editing system, such as trying different reverse transcriptases or other methods. For now, we’d like to try it on our own, but like you said, it’s good to have this opportunity in case it doesn’t work out." />
      <QaBox q="Yeah, I think working with patient cells is one thing, but just be aware that these models and assays typically take a lot of time—easily half a year, and that’s considered fast to get them up and running. Unless you're in a lab that already has experience with growing organoids, it could be very challenging to start from scratch." a="However, you can always try. The team in Paris that we know very well—they are incredibly kind, world-class experts in what they do, but they are also under a lot of pressure. They use these technologies not only for research but also to diagnose patients. What the French team has managed to do is show that if a patient’s cells respond to certain drugs, the government allows those drugs to be administered to the patient. You can imagine how important these experiments are, as they can directly impact patients' lives, which naturally takes the highest priority." />
      <QaBox q="Yeah, we recognized that too. We talked with the CF team at the University Clinic in Münster and asked about using their Ussing chamber, but they are really overworked with it. That’s why we reached out to you about it. But it’s completely fine, as we mentioned before." a="I'm going to put it bluntly: Ussing chamber experiments, while they are highly regarded and provide valuable data, are a real pain to perform. They are incredibly time-consuming and have a very low throughput. A typical setup has four chambers, so you always need to do repeats. In the best-case scenario, you can test two conditions at a time. If you have a very experienced person, they might be able to run eight samples, but they would have to stay with the machine for four to five hours, maintaining constant attention. With multiple technicians, as is the case in France, you might manage to run 16 samples a day." />
      <QaBox q="On top of that, the cells need to be differentiated properly, and you have to know how to handle them correctly. The medium required is very expensive, and working with these cells is almost more of an art than a science. You have to know when the cells look 'happy' or not because you don't want to waste time on cells that aren't in good condition. I've run quite a few of these assays myself, and while they are great for CF work and provide results that are relevant to patient outcomes, they are technically challenging and very demanding." a="If you want a functional output to show that the CFTR protein is working again, I would recommend starting with one of the easier models, like organoids. We also have in our lab 16HBE cells with a YFP sensor. I don't know if you've heard or read about that. These cells express YFP, which is sensitive to halide ions, including chloride and iodide. When you add a buffer containing these ions to the cells, the YFP intensity quenches. This is something we typically use in our experiments." />
      <QaBox q="For wild-type cells, you see a rapid and dramatic quenching because CFTR allows these ions to enter the cells. In cells with the mutation, there’s no quenching because the channel isn’t working. While it’s less relevant because these aren't patient cells, it’s closer to reality. The 16HBE cell line is an airway epithelial line, and the expression of CFTR is endogenous, so it’s not at the exaggerated levels you might see in more artificial models like HEK cells." a="Using the YFP assay could be a good alternative or a Plan B for getting a functional readout. This assay is medium to high throughput—you can run entire 96-well plates in about half an hour. All you need for this is the cells and a plate reader that can measure fluorescence and inject the buffer. If you don’t have a plate reader with an injection system, you can also manually add the buffer and quickly place the plate in the machine." />
      <QaBox q="Yes, that sounds quite good. I think we’ll definitely consider that as a method." a="If you have a little more time, I wanted to ask about the pegRNA. You stabilized it with a stem loop or some kind of motif in the paper, like the trevopreQ1. Did you test other motifs as well, or...?" />
    </>,
    references: <MattijsInterviewSources />,
    summary: "",
    months: ""
  },
  {
    vorname: "Nicole",
    nachnname: "Friedlein",
    job: "Research group on fundamental rights",
    affiliation: "Universität Potsdam",
    pictureurl: pics['nicole'],
    tag: "Academia",
    heading: "Discussion on how health insurance companies manage cystic fibrosis patients and gene therapy treatments",
    interviewtabid: "nicole",
    cardtext: "",
    language: "de",
    quote: "Public health insurance operates under an economic efficiency principle, meaning the most cost-effective treatments are preferred. But if gene therapies become the only treatment option for certain conditions, they will likely have to be included in the coverage, which could be a challenge for the system.",
    aimofcontact: "The main objective of the contact was to learn from the discussion on issues related to cystic fibrosis (CF), gene therapy, health insurance processes and regulatory pathways. In particular, we wanted to understand the real-world challenges and technical aspects of gene editing, especially prime editing, as well as the complexities of approval and reimbursement of gene therapies for CF patients.",
    insights: "The regulatory approval process, particularly by the European Medicines Agency (EMA) for advanced medical devices, has highlighted the bureaucratic hurdles that gene therapies must overcome. We learned that such therapies for cystic fibrosis have to navigate complex European and German regulatory systems. The discussion on the AMNOG process was crucial. We learnt that the additional benefit of a therapy is assessed for reimbursement by the statutory health insurance funds. We implemented this insight in our project by considering the long-term regulatory and economic effects as important milestones for therapy development. We also gained insight into how public and private health insurers may differ in their reimbursement of such therapies. Public insurers have stricter guidelines, while private insurers can be more flexible, but both require strict justification, especially for rare diseases such as cystic fibrosis. Information on newborn screening and genetic counselling covered by public health insurance was crucial to understanding how preventive measures for CF are managed. This underlines the importance of early intervention and diagnosis in our project. Atypical forms of CF, where health insurance companies do not cover treatment due to non-standardised test results, were identified as a key problem. This helped us to recognise the need for more adaptable insurance policies and clearer pathways for the treatment of atypical cases in our project plans. The debate about whether healthcare systems can afford the high costs of gene therapies highlighted an important issue in the current medical landscape. We have incorporated this insight into our project by discussing possible cost-effective alternatives and the need for thorough cost-benefit analysis in the development of treatments.",
    implementation: "After the interview, we further tailored our project to focus on a simple delivery method. To gain an overview of the regulatory requirements and to better deliver the project, one of our team members attended a GxP course to ensure we met all the necessary standards. To deepen our knowledge of entrepreneurship, we conducted further interviews with start-ups and industrial companies, which gave us important insights into practical implementation. These steps ensure that our project is not only based on scientific research, but also takes into account the practical, regulatory and social aspects that are crucial to bringing new CF therapies to the market. We are currently developing strategies to successfully implement our ideas and the project in the future.",
    interview: <>
      <QaBox q="To start with this interview. Do you have any questions about this project?"
        a="Are you writing a paper on this, or are you conducting actual laboratory research? Or is it primarily literature review? How does your work look?" />
      <QaBox q="It’s not just literature review, though we do start with that. We have a lot of lab work ahead of us. Ideally, we would have a finished construct to present at the end, maybe even a functional gene therapy, though that’s quite ambitious and probably not possible in the short time frame. We’re working on various gene-editing approaches and testing plasmids in HEK cells. We are also exploring Prime Editing and trying to improve its efficiency using different reverse transcriptase enzymes. So, it’s a mix of lab work, literature research, and preparing for a presentation at a competition."
        a="Are you writing a formal paper?" />
      <QaBox q="We’re not writing a formal text-based paper, but everything will be available on a website. We will document most of our work on the website, with sub-pages detailing lab work, interviews, and research."
        a="What exactly is Prime Editing, and how does it differ from altering the germline? Where in the genome does this therapy act?" />
      <QaBox q="Our current plan is to deliver the therapy via a lipid nanoparticle system, which will be inhaled and go into the lungs. While cystic fibrosis (CF) affects all mucus membranes, the lungs are the most critical area, so we’re focusing on that. The therapy will only target surface cells in the lungs, not the basal cells responsible for producing new lung cells."
        a="Thank you for giving me insights into your project." />
      <QaBox q="Do you know how cystic fibrosis (CF) approval works in terms of health insurance and regulatory processes?"
        a="The approval process for gene therapies is primarily done through the EMA (European Medicines Agency) under specific EU regulations for Advanced Medical Products, including gene therapies. There is also a national approval process in Germany for individualized treatments, but large-scale therapies must go through the EU process." />
      <QaBox q="Can you share more about the approval and reimbursement processes for CF treatment?"
        a="The approval process is separate from reimbursement by public health insurance. CF is considered a rare disease if it affects fewer than five out of 10,000 people, and treatments for rare diseases often face special reimbursement challenges. If more than five out of 10,000 people are affected, the disease is relatively common, and approval and reimbursement go through a different procedure known as the AMNOG process. For more common diseases, an additional benefit (Zusatznutzen) must be demonstrated during the approval process." />
      <QaBox q="Have you heard about issues with reimbursement from private insurance companies?"
        a="We’ve heard that private insurance companies can make it difficult to get treatments reimbursed, especially experimental ones. One of our colleagues almost had to go to court to get his treatment reimbursed by his private insurer, which was quite expensive. Eventually, he switched to public insurance, but the situation was difficult." />
      <QaBox q="Why did your colleague have issues with private insurance?"
        a="He was privately insured, but the treatment was very expensive, around €16,000 per month, and the insurance company was reluctant to cover it." />
      <QaBox q="Do you need legal information for your project?"
        a="Both. We want to be well-informed to identify potential obstacles early on, such as legal restrictions or bans on altering certain chromosomes. Although we won’t be running clinical trials, understanding the regulatory landscape is crucial for our future planning." />
      <QaBox q="How does genetic counseling and testing work for CF?"
        a="Genetic counseling and testing are usually covered by health insurance if there’s a medical reason, such as a family history or suspicion that the parents might be carriers. However, if both parents are healthy and there’s no family history of CF, insurance might not cover the tests." />
      <QaBox q="Are there differences between public and private insurers for genetic tests?"
        a="Public insurance has different regulations than private insurance, but I’m not entirely sure if that leads to different decisions regarding genetic testing. I can look into the public insurance regulations if that would be helpful." />
      <QaBox q="Is newborn screening for CF covered by health insurance?"
        a="Yes, newborn screening is part of a set of health examinations for children and adolescents, regulated under §26 SGB V (Social Security Code). Since it’s part of the regular screening process, it’s covered by health insurance without additional requirements." />
      <QaBox q="How does public insurance handle CF treatment when a test comes back negative?"
        a="Public health insurance works with standardized guidelines, and if a test comes back negative, it may no longer meet the criteria for coverage. However, if a doctor reconfirms the diagnosis, the treatment should continue to be covered." />
      <QaBox q="Is there no rule that says genetic diseases, once diagnosed, should remain covered since genetics don’t change?"
        a="In theory, yes. But the guidelines are usually based on medical evidence at the time, and re-testing can sometimes lead to complications in terms of coverage if the result differs. However, with proper medical documentation, it should be possible to maintain coverage." />
      <QaBox q="Have recent changes in gene therapy costs impacted public health insurance?"
        a="Not much has changed. It’s a political and societal question—how willing are we to finance these expensive therapies? Right now, public health insurance operates under an economic efficiency principle, meaning the most cost-effective treatments are preferred. But if gene therapies become the only treatment option for certain conditions, they will likely have to be included in the coverage, and it could be a challenge for the system. There are also ongoing price negotiations between insurers and manufacturers." />
      <QaBox q="Do patents play a significant role in keeping gene therapy costs high?"
        a="Yes, patents certainly influence the price, but the production of gene therapies is inherently expensive due to the complex research and manufacturing process." />
      <QaBox q="Would private supplemental insurance be an option for covering expensive gene therapies?"
        a="It’s possible that private supplemental insurance could cover these therapies if public health insurance doesn’t. However, this raises concerns about equity and accessibility. If public insurance doesn’t cover it, the burden might fall on private insurance, which could create disparities in access to treatment." />
      <QaBox q="Is gene therapy research driven more by biology or medicine?"
        a="It’s definitely interdisciplinary. Both biologists and medical professionals contribute. For example, at our university, the medical and biology faculties collaborate closely. Biologists usually handle the research, while medical professionals focus more on clinical applications." />
      <QaBox q="Do biologists or medical professionals develop gene therapies?"
        a="In terms of development, it’s mainly biologists and biotechnologists. Medical professionals get involved primarily in clinical trials. Some doctors do research, but they’re often needed in hospitals, so hands-on development is mostly handled by molecular biologists or biotechnologists." />
      <QaBox q="Does research in genome medicine and gene therapies come from biology, medicine, or both?"
        a="It’s mainly interdisciplinary. A lot of funding comes from industry, like BioNTech, or foundations like Mukoviszidose e.V., which funds research on cystic fibrosis. But in terms of practical research, it’s usually biologists or biotechnologists. Without industry support, research can struggle due to a lack of funding, so having backing is essential." />
    </>,
    summary: "",
    months: ""
  },
  {
    vorname: "Katrin",
    nachnname: "Westhoff",
    job: "physiotherapist",
    affiliation: "Independent",
    pictureurl: pics['westhoff'],
    tag: "Medical Professional",
    heading: "In-Depth Visit to Specialized Physiotherapist for CF Breathing Therapy",
    interviewtabid: "westhoffvisit",
    cardtext: "",
    language: "de",
    quote: "Children are the world's best “mucus hiders”.",
    aimofcontact: "In the interview with Katrin Westhoff [Link], she invited us to join a few physiotherapy sessions – not just as spectators but as participants. We gladly accepted and visited her in her practice. Over a few hours, we took part in four sessions with different children – not all of them CF patients.  ",
    insights: "During the sessions, we could ask Katrin as well as the respective parents and children questions. We learned that breathing therapy is also useful for other illnesses and that you can easily do some of the exercises yourself. Despite having cystic fibrosis, the children were better at the breathing exercises than we and Katrin were! The sessions take 30 to 60 minutes and include both manual therapy and playful elements to help engage the children. Most older children range from mildly unhappy to enthusiastic, but babies often cry during the treatments as it feels uncomfortable. This is often hard on the parents even though the treatment brings good results. A lot of children tend to hide that they have mucus sitting in their lungs by suppressing coughs. Especially with young children, it is important to stay on top of it and do regular breathing therapy even if it seems like it is currently not necessary. We also learned about the various informational material aimed at children to help explain therapies and symptoms to them and what accessories for breathing therapy there are. For example, a flutter is to train breathing out forcefully by breathing against a small weight and a binder can be worn at night to promote deep breathing. ",
    implementation: "The most important thing was that both Katrin and the parents agreed that the children were able to inhale at an early age and that there were generally no physical problems with inhalation in general. This reinforced our decision to work towards delivery by inhalation. It was very interesting to see the different ways children deal with their exercises and hear about the progress they made.  ",
    text: [<ol>
      <li>
        <strong>Robin (&gt;10)</strong>
        <p>Robin will soon start 4th grade and takes modulators. Since taking them, many problems have subsided. No regular pneumonia with long hospital stays and the mucus comes out easier. Nevertheless, Robin still goes to physiotherapy regularly to do manual breathing therapy to get the mucus out. Katrin tells us how the mucus changes color the longer it stays in the lungs. The new mucus is white, and the older mucus gets yellow first and then gets darker with time until it reaches a black color. Nowadays, Robin rarely has dark mucus or clumps, but we can still hear the rustling as Katrin starts the autogenous drainage (Autogene Drainage) by pressing on Robin's chest. The goal is to get out the mucus deep in the lungs. To do that, Robin must repeat the routine – breathing in deeply, holding, breathing out – multiple times and then cough and spit the mucus out. Sometimes it works, but other times the mucus does not come out easily. While according to Katrin the autogenous drainage is the gold standard, they do other useful exercises, too. For example, pressing the Vojta points (which the children call “the magic points”) on the chest to activate a deep breathing reflex and get air into parts of the lungs that may not have been used previously. Or physical activity such as climbing a few steps on a climbing ladder and hanging on it to stretch the thorax muscles.</p>
      </li>
      <li>
        <strong>Sam (&lt;10) & Alex (&lt;10)</strong>
        <p>Sam and Alex are siblings and do not have CF but another affliction that causes a persistent cough. They come together with a parent twice a week and do hanging exercises from the ceiling, nasal showers with needleless syringes, and the “magic points.” Katrin also checks their lungs for mucus in a similar manner to autogenous drainage. We, too, tried to do the nasal shower, and being a grown-up really does not guarantee being able to do that properly! This highlighted that the children know all their exercises by heart at a young age. On request, their parent told us that the physiotherapy made a big difference for both of them.</p>
      </li>
      <li>
        <strong>Toni (&lt;5)</strong>
        <p>Toni has a light version of CF and has been doing physiotherapy with Katrin since shortly after birth. In contrast to most children we met or talked about, Toni refuses medication. Modulators are a possibility, but them and 'everything stinky' is a no-go, even though inhaling would be very beneficial due to the mucus buildup. Most exercises result in crying and screaming, which is very exhausting for the child. Due to the light nature of Toni's variant, they are not in danger, but a permanent therapy would be very beneficial.</p>
      </li>
      <li>
        <strong>Chrissi (&gt;10)</strong>
        <p>Chrissi takes modulators and will soon take a trip to a water park with some friends. Katrin teaches us that when the children do not breathe out properly, air stays in the lungs and causes hyperinflation – with which it is actually harder to float in water! After the manual drainage, Katrin gets all of us glasses with water and dish soap and straws. Blowing bubbles is a playful way to train how to properly breathe out by either trying to blow bubbles as long as possible or trying to make an existing bubble as big as possible!</p>
      </li>
    </ol>,],
    summary: "",
    months: ""
  },
  {
    vorname: "Julia",
    nachnname: "XXX",
    job: "parent",
    affiliation: "independent",
    pictureurl: pics['julia'],
    tag: "Patient",
    heading: "Interview with a CF Parent About Their Experience and Treatment Needs",
    interviewtabid: "julia",
    cardtext: "",
    language: "de",
    quote: "At first, our world fell apart. I still remember the conversation with the doctor. ",
    aimofcontact: [<p>We learned from our discussion with Max [Link Max] that cystic fibrosis (CF) has a profound impact on the whole family – not just the patient. In order to gain further insight into this subject, we sought to engage with the next of kin of CF patients.
      We were able to make contact with Julia through the self-help group of Mukviszidose e.V. [Link https://www.muko.info/ ], of which Max is a member. She subsequently reached out to us following Max's request for potential candidates for an interview with a patient group.
      She and her husband have a six-year-old daughter carrying the F508del mutation in the CFTR gene and a toddler without CF.  </p>],
    insights: [<p> The interview with Julia shifted our focus to a new group of stakeholders: The patient’s support systems. Most people do not get genetically tested before having children and due to that, many people could get in the position of having a loved one with CF.
      We considered the societal impacts, such as the rising health care costs, which Nicole Friedlein emphasized during our interview. She explained how the long-term nature of treatment, frequent hospital visits, and the need for specialized medications place a significant
      financial burden on both patients and the health care system. This insight shaped our understanding of the broader economic challenges faced by families and institutions involved in managing chronic illnesses. Meanwhile, Julia brought attention to the psychological impact,
      stressing the emotional strain that accompanies not only the illness itself but also the financial pressures. She also showed us more perspectives on parenting of children with CF, than we heard before, and told us about the way from the first diagnosis to growing accustomed
      to and living with a child with CF. Julia also confirmed that most children will have no issue using an inhalative therapy like we envision our gene therapy to be and shone light onto the comparatively very good situation for CF patients in Germany. </p>],
    implementation: [<p> This interview helped us confirm the delivery method we planned to use as we were previously concerned how and if children would be able to use the inhalative therapy. Besides that, Julia gave us further insights into the emotional side of
      dealing with CF and we were able to discuss the situation for patients in Germany in comparison to other countries better in later interviews [Link Joshua]. </p>],
    interview: <>
      <QaBox q="Can you tell us a bit about your family? How old are your children and yourselves?" a="I’m 37, my husband is 44, and our daughter is six, turning seven soon. We also have a son who’s about a year and a half." />
      <QaBox q="Does your son also have cystic fibrosis?" a="No, he doesn’t." />
      <QaBox q="When was your daughter diagnosed with cystic fibrosis?" a="Right after birth. She was transferred to a bigger hospital due to an intestinal blockage and had surgery. After about two to three weeks in intensive care, the cystic fibrosis diagnosis came through newborn screening. At that time, the results took longer to process than they do now." />
      <QaBox q="That intestinal issue can happen for many reasons, right?" a="Yes, it was all new to us. The beginning was difficult, but things have gotten better since then, and we’re very grateful." />
      <QaBox q="How did you feel when you first heard the diagnosis?" a="It felt like our world was falling apart. I still remember the moment—it was like being in a movie. We were told in a separate room, and it felt overwhelming. One doctor even suggested we go home to think about it in peace, but all I could think about was returning to my child. It was a lot to take in, especially thinking about how we’d tell our family." />
      <QaBox q="That sounds incredibly hard. How did you handle it as time passed?" a="It was tough, but we were fortunate to have a doctor who really understood what we were going through, as he had a disabled child himself. He never scared us unnecessarily and guided us step by step, which made a big difference. We know many families who live in constant fear, but since those first months, we’ve learned to manage the situation without being overwhelmed by fear." />
      <QaBox q="Did any particular support help your family adjust to the diagnosis?" a="Yes, the rehab program we attended was a huge help. It was a family-oriented program, so my husband could be there too, which was important since I manage most things day-to-day. It really helped our daughter realize she’s not alone—she met other kids with similar conditions, which was a huge comfort." />
      <QaBox q="How did you explain the illness to your daughter?" a="We try to give it as little attention as possible in daily life. She’s been inhaling medication since she was eight weeks old, and it’s just part of her routine now. Thankfully, she doesn’t fight it or question it much, and her school and kindergarten haven’t made a big deal of it either, which is what we wanted." />
      <QaBox q="Does she ever ask about her illness compared to her younger brother, who doesn’t have cystic fibrosis?" a="She does sometimes ask why she’s sick and he’s not, but she’s not upset by it. We’ve made sure not to give her any special treatment because of her illness, which can be hard at times, but we want her to understand that her illness doesn’t define her." />
      <QaBox q="That sounds like a good balance. What about medications—did she start on any special treatments?" a="Yes, she started on Orkambi at around three years old but had to stop briefly due to high liver values. Now she’s on Kaftrio, which she started shortly before her sixth birthday, and it’s been going well." />
      <QaBox q="Did you face any issues with the health insurance for covering these medications?" a="Fortunately, no. We have statutory health insurance, and they’ve covered everything without any issues. We’ve heard it can be more complicated for those with private insurance." />
      <QaBox q="Have you ever had difficulties with access to medication?" a="Yes, there have been times when we’ve had to wait a few days for certain medications, like Kreon or antibiotics, especially in the winter. But we always plan ahead and keep a buffer, so we’ve never been without what we need." />
      <QaBox q="What would you say has been the most affected area for your daughter?" a="Her intestines are the most affected. Before she started Kaftrio, she had fatty stools and frequent bowel movements, even with the right Kreon dosage. Since starting Kaftrio, this has improved significantly." />
      <QaBox q="What kind of support would you have liked to receive earlier?" a="We wish we had been given more information about available services early on. We found out about Mukoviszidose e.V. from another family, not from our doctor. It would have been helpful to know about these resources right from the start." />
      <QaBox q="How about psychosocial support?" a="Initially, we didn’t have any psychological support—our doctor took care of everything. Now, where we live, there are more resources, and we think it’s a good thing. The rehab helped a lot in coming to terms with everything. We wish we had known about such services sooner." />
      <QaBox q="Does your daughter do physiotherapy?" a="Yes, once a week for about an hour. She’s been going since she was discharged from the hospital, and she has a close bond with her physiotherapist. They’ve been working together since she was a baby, and she goes by herself now." />
      <QaBox q="Are there any restrictions for her in terms of physical activities?" a="No, not really. She does dancing once a week, physiotherapy, and she’s even done a swimming course without any problems." />
      <QaBox q="How do you handle communicating about her illness?" a="We try not to make a big deal of it. When I looked for information, I found what we needed. There’s nothing we’ve really felt was missing." />
    </>,
    summary: "",
    months: ""
  },
  {
    vorname: "Joshua",
    nachnname: "Bauder",
    job: "parent and activist",
    affiliation: "CF vests worldwide",
    pictureurl: pics['joshua'],
    tag: "Patient",
    heading: "Interview with a CF Parent and Global Advocate on Worldwide Support and Perspectives",
    interviewtabid: "joshua",
    cardtext: "",
    language: "en",
    quote: "We’ve had to sit by and watch people die, knowing that better treatment exists but is inaccessible. ",
    aimofcontact: [<p>We contacted the organization <a href="https://www.cfvww.org/">CF vests worldwide</a> with the aim to hear more diverse perspectives beyond Germany.
      After the founder Rod connected us with Joshua, Joshua was so kind to conduct an interview with us not only about the perspectives and
      stories he heard but also about his personal experiences with his daughter and living in a country where CF care is very hard to get. Joshua
      (from the USA) and his family live in Thailand where he and his wife run a children’s home. Their daughter is the only child with CF.</p>,
    <p>It is possible to learn more about Joshua and his family though the <a href="https://thebonnellfoundation.org/cf-vests-worldwide/">
      podcast of the Bonnel foundation</a>.</p>],
    insights: [<p> Joshua showed us just how dire the situation is for CF patients is in some regions. It was shocking to hear there is only one doctor
      knowledgeable about CF in Thailand and that many doctors dismiss the possibility of CF due to racial bias and misinformation. Additionally, we confirmed how much the accessibility
      of care depends on the healthcare system, as we already touched on during the interview with Nicole Friedlein [link]. On the parenting level, Joshua brought in many perspectives contrary to what we previously heard. In the interview with Max [Link], we learned he vehemently avoids ponding water while Joshua’s daughter is allowed to roam around with no such restrictions. Neither have chronic infections.</p>],
    implementation: [<p>The interview with Josh made us realize we too needed to look at the reason why we chose F508del. Did we, too, fall for bias?
      Despite a change of target not being feasible anymore, we looked into it and traced back our steps that led to our decision. We did not find as much
      information about other mutations when first researching cystic fibrosis, especially in the context of prime editing. Mattijs Bulceans's paper on
      targeting the mutations L227R and N1303K <TabScrollLink tab="joshua" scrollId="desc-1" num="1" /> was one of few papers. After explicitly searching for cystic fibrosis records for specific countries and
      regions, we uncovered a moderate number of papers examining CF in Asia and other regions we previously did not know much about. The very first article
      supported Joshua's hypotheses and painted a sad picture: Among other things, it describes the case of a four-month-old boy who was diagnosed with cystic
      fibrosis. Nothing unusual in itself, but the circumstances are depressing. Two of the three siblings born before him died within months of birth and had
      previously presented with symptoms of cystic fibrosis. He was the first to be diagnosed. A sweat test aimed at cystic fibrosis was not available at the
      hospital, so one was improvised. Later on, a genetic test revealed the presence of 508del. <TabScrollLink tab="joshua" scrollId="desc-2" num="2" /> We found ourselves and our lack of knowledge in good
      company as we found papers as new as from 2020 (14 years after the previously mentioned paper) containing statements such as “recent reports suggest
      that CF does occur in Asia” <TabScrollLink tab="joshua" scrollId="desc-3" num="3" />. Fortunately, there is a rising number of cystic fibrosis experts for Asia and other previously overlooked regions
      such as Africa. <TabScrollLink tab="joshua" scrollId="desc-4" num="4" /> We chose to not only look at the scientific data but also into anecdotal evidence. To find the latter, we searched official
      and private websites and chatrooms for information and experiences of patients. In the end, we found narratives from most ethnic backgrounds
      about being dismissed and often misdiagnosed. Of course, this is not an occurrence unique to cystic fibrosis. Our conclusion is that yes,
      we did fall for bias. But regardless of ethnicity, 508del occurs and is overall the most prevalent mutation as was confirmed in our interview
      with CF expert Sriram .... This experience was uncomfortable as we felt the pressure to be thorough and deliver a perfect project. What would
      have been more devastating than realizing we made a wrong choice at the very core?  We made the conscious decision to invest our resources into
      figuring out if we indeed made a mistake and we want to encourage other teams to do the same. iGem stands for innovation – but also for growth.
      Especially in the context of Integrated Human Practices, it is important to examine both the positive and the negative to create a project with a
      future.  </p>],
    pictureurl_interview: "",
    references: <JoshuaInterviewSources />,
    summary: "",
    months: ""
  },
  {
    title: "Prof. Dr.",
    vorname: "Erhard",
    nachnname: "Wischmeyer",
    job: "Research Group Cellular Neurophysiology",
    affiliation: "Universität Bielefeld",
    pictureurl: pics['wischmeyer'],
    tag: "Academia",
    heading: "Discussion on Techniques for Measuring CFTR Channel Functionality",
    interviewtabid: "patchclamp",
    cardtext: "",
    language: "de",
    quoteNachname: "Guckes",
    quoteVorname: "Isabell",
    quote: "Initially we hadn't considered patch-clamp measurements in our set of downstream applications, but it’s proven to be an exceptionally sensitive method for assessing CFTR conductance.",
    aimofcontact: [<p>As part of our project, we aimed to demonstrate the functionality of the CFTR ion channel, after restoring
      it through our optimized Prime Editing, by using Patch-Clamp measurements. To ensure the optimal use of the
      Patch-Clamp and to gain an insight into electrophysiology, we asked experts from the medical faculty at
      Bielefeld University to critically examine our measurement planning. Prof. Dr. Erhard Wischmeyer, an
      experienced scientist in this field who has worked at the Max Planck Institute for Biophysical Chemistry
      in Göttingen, the development site of the Patch-Clamp technique<ScrollLinkWithChild targetId="desc-1"><sup>1</sup></ScrollLinkWithChild>, and currently leads the Cellular
      Neurophysiology working group at Bielefeld University, seemed to be an ideal interviewee. His
      knowledge and experience promised valuable insights and advice for conducting and optimizing our
      experiments. </p>],
    pictureurl_aim: "https://static.igem.wiki/teams/5247/photos/for-wiki-texts/hp-patch-clamp/wischmeyer-interview.webp",
    insights: [<><p>Prof. Dr. Wischmeyer taught us about the workflow of the Patch-Clamp technique. He highlighted the need
      for specialized electrodes and glass pipettes that must form a smooth surface devoid of the extracellular
      matrix (ECM). Additionally, he pointed out that measuring CFTR conductivity with the Patch-Clamp technique
      poses a technical challenge due to the low currents involved<ScrollLinkWithChild targetId="desc-2"><sup>2</sup></ScrollLinkWithChild>. He recommended using expression vectors
      for overexpressing the CFTR gene in HEK cells instead of epithelial cells from a nasal swab to achieve
      better results. Since Patch-Clamp measurements require a very sensitive testing environment, even
      challenging for the most experienced scientists, Prof. Dr. Wischmeyer invited us to conduct the
      measurements together with members of his group.
    </p>
      <p>In addition to the Patch-Clamp technique, Prof. Dr. Wischmeyer informed us about E-cis measurements as a
        current electrophysiological measurement method alongside the Patch-Clamp technique. This method allows
        the measurement of the membrane potential above and below a monolayer of confluent cells<ScrollLinkWithChild targetId="desc-3"><sup>3</sup></ScrollLinkWithChild>. Consequently,
        it enables precise measurement of conductivity dependent on CFTR expression. </p>
    </>],
    implementation: [<> <p>We decided to use HEK293T cells lines which do overexpress the
      correct CFTR and those which express CFTR with F508del for the Patch-Clamp measurements. To conduct the
      Patch-Clamp experiments, we contacted the Cellular Neurophysiology group to perform the necessary
      measurements. It was a pleasure to work together with Dr. Oliver Dräger[Link], who is working as a post-doc for
      the Cellular Neurophysiology working group at Bielefeld University. He taught us about the Patch-Clamp
      method and spent his valuable time supporting our project by guiding our Patch-Clamp measurements. </p>
      <p>In summary, through the interview with Prof. Dr. Wischmeyer and the collaboration with his employee
        Oliver Dräger, we gained valuable insights and optimized our approach to effectively investigate and
        measure the functionality of the CFTR ion channel, thereby determining the efficiency of our Prime
        Editing strategy. </p></>],
    pictureurl_implementation: "https://static.igem.wiki/teams/5247/photos/for-wiki-texts/hp-patch-clamp/bild-patch-clamp-isi-oliver.webp",
    pictureurl_interview: "https://static.igem.wiki/teams/5247/photos/for-wiki-texts/hp-patch-clamp/bild-interssierte-wissenschaftler-oho.webp",
    references: <WischmeyerSources />,
    interview: <>
      <QaBox q="Can you educate us about your academic career?" a="I did my doctorate 30 years ago at Bielefeld University and then worked at the Max Planck Institute in Göttingen a lot with the patch-clamp technique. Today, I’m head of the working group Cellular Neurophysiology of the medicine faculty of Bielefeld University." />
      <QaBox q="What new methods are currently available in electrophysiological research?" a="One of the latest methods is E-cis measurements. These make it possible to examine a monolayer of confluent cells and to measure the membrane potential both above and below. The change in conductivity can be analyzed for instance as a function of CFTR expression." />
      <QaBox q="How can we proceed with the investigation of CFTR in different cell cultures by patch-clamp?" a="You can study CFTR expression in HEK cells, which allows for a measurable change in chloride conductance. I am not sure whether we will be able to investigate CFTR sufficiently in epithelial cells which you want to collect from your CF patient friend and your team members. That is something we have to try out." />
      <QaBox q="How challenging is the measurement of CFTR conductance in epithelial cells?" a="CFTR in epithelial cells has very low conductivity in the femtoampere range. Therefore, extremely sensitive testing is necessary to obtain meaningful results." />
      <QaBox q="How challenging is the patch-clamp measurement of CFTR conductance in epithelial cells?" a="The project could take at least one year, even for experienced researchers." />
      <QaBox q="What technical challenges do we face in implementing the patch-clamp measurements?" a="One of the biggest challenges is measuring the current across the entire cell, as we do not want to carry out single-channel measurements, but rather record the current across cells with a strongly expressing vector carrying the gene for the ion channel." />
      <QaBox q="What requirements must be met for cultivation and transfection before the patch-clamp measurement?" a="You have to cultivate the cells on poly-lysine and laminin and use round coverslips of 10 mm diameter to prepare them for measurement. For identification of positive transfectants, we use GFP co-transfected cells in our working group, you should think of something like that as well. A transfection rate of 10 % is sufficient to gain enough cells for the measurement. You can think of optimizing your transfection by using Lipofectamine2000, which works well for our working group." />
      <QaBox q="Who could help us with the patch-clamp measurements?" a="The patch-clamp devices are heavily utilized in our working group, so you probably cannot perform measurements on your own. However, postdocs could support you for some measurements. Dr. Oliver Dräger is available as a contact person of my working group." />

    </>,
    summary: "n summary, through the interview with Prof. Dr. Wischmeyer and the collaboration with his employee Dr. Oliver Dräger, we gained valuable insights and optimized our approach to effectively investigate and measure the functionality of the CFTR ion channel, thereby determining the efficiency of our prime editing strategy.",
    months: ""
  },
  {
    title: "Prof. Dr.",
    vorname: "Stefan",
    nachnname: "Hammer",
    job: "Junior Professor of Organic Chemistry and Biocatalysis",
    affiliation: "Universität Bielefeld",
    pictureurl: pics['hammer'],
    tag: "Academia",
    heading: "Safety Briefing and Laboratory Practices Advice",
    interviewtabid: "hammer",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Katharina",
    nachnname: "Kolonko",
    job: "",
    affiliation: "",
    pictureurl: pics['kolonko'],
    tag: "Academia",
    heading: "First steps in LNPs",
    interviewtabid: "kolonkofirst",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    vorname: "Svenja",
    nachnname: "Vinke",
    job: "PostDoc at Harvard Medical School",
    affiliation: "Harvard Medical School",
    pictureurl: pics['svenja'],
    tag: "Academia",
    heading: "",
    interviewtabid: "svenja",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: [<p>We contacted Svenja Vinke, a former iGEMer from Bielefeld, to get her insight and her opinion regarding the use of phage assisted continuous evolution
      (PACE, see engineering cycle 1[Link]) for our prime editing optimizations. Svenja works at the iGEM Safety and Security Committee. Additionally, she was part of the Biosafety and Security Award Team of Bielefeld University in 2016.</p>],
    insights: [<p>Svenja explained, that a PACE approach is not feasible to use for optimization of our nickase candidates because of several reasons:</p>,
    <ul>
      <li>Implementing a PACE system takes way too much time to use for our project.</li>
      <li>Endonucleases might be too big to optimize using PACE.</li>
      <li>Unspecific cutting or nicking in the bacterial genome kills the cells, which makes optimization of endonucleases very challenging.</li>
      <li>Prime editing in E. coli cells is less effective compared to human cells, which might impair the evolution process.</li>
    </ul>
    ],
    implementation: [<p>On the basis of Svenja’s and other opinions on the topic, we decided not to try implementing a PACE system. </p>],
    summary: "",
    months: ""
  },
  {
    vorname: "Max",
    nachnname: "Beckmann",
    job: "Bielefeld University",
    pictureurl: pics['max'],
    tag: "Patient",
    heading: "Consultation on University Hygiene Risks and Improvement for Hygiene Concept",
    interviewtabid: "maxhygiene",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Eva-Maria",
    nachnname: "Berens",
    job: "Ethics Committee of Bielefeld University",
    affiliation: "Bielefeld University",
    pictureurl: pics['berens'],
    tag: "Academia",
    heading: "Bioethics: Best Practices for Handling Patient Data and Primary Cells", /* Guidance from Ethics Committee on Best Practices for Patient Data and Primary Cells */
    interviewtabid: "berens",
    cardtext: "",
    language: "de",
    quote: "The most important thing is a detailed letter of consent and a detailed privacy policy. This must explain to the patient as precisely as possible what happens to their cells and data, as well as the time span, which people are involved or have access to the cells and how.",
    aimofcontact: "The aim of the interview was to get an answer to the question of whether we need an ethics vote for our project or not and to obtain guidelines for dealing with patient cells regarding ethical issues and data protection. ",
    insights: "The discussion was very informative in terms of how we should approach this topic and focused primarily on the important factors that need to be considered when planning the handling of patient cells. These include which legal principles need to be observed, data protection, ethical considerations and, above all, detailed and specific information for the donor. It also made us look at the situation from many different angles and consider the risks of worst-case scenarios. Overall, this interview was very useful to us, and we were able to use the information we gained to develop a kind of guideline that allowed us to approach this sensitive topic, which was new to us, with a certain degree of confidence. ",
    implementation: "Based on the knowledge we have gained, we have drawn up guidelines for our handling of the cells. We used this guide when handling the patient cells, to ensure they were handled in an ethically correct manner.",
    summary: "",
    months: ""
  },
  {
    vorname: "Collaboration",
    nachnname: "",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "LNP Handbook",
    interviewtabid: "handbook",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    vorname: "Benjamin",
    title: "Dr.",
    nachnname: "Winkeljann",
    job: "Co-Founder and CEO at RNhale",
    affiliation: "RNhale",
    pictureurl: pics['winkeljann'],
    tag: "Industry",
    heading: "Rnhale",
    interviewtabid: "rnhale",
    cardtext: "",
    language: "de",
    quote: "Spray-drying LNPs is a groundbreaking approach that enhances stability and enables efficient pulmonary delivery of mRNA, paving the way for innovative therapies for conditions like cystic fibrosis.",
    aimofcontact: [<p>As part of our development process of an innovative, effective pulmonary delivery of therapeutic mRNA to fight cystic fibrosis,
      we conducted an interview with Dr. Benjamin Winkeljann, who is the Co-Founder of <a href="https://rnhale.com/">RNhale</a>. Dr. Benjamin
      Winkeljann has a wealth of experience in the field of RNA therapeutics and nanotechnology. His background includes extensive research in the
      development of lipid-based delivery systems, focusing on optimizing stability and efficacy for therapeutic applications. Winkeljann’s work
      is supported by cutting-edge research from academic institutions, including collaborations with Professor Olivia Merkel from the
      Ludwig-Maximilians-Universität in Munich, Germany, since his doctoral thesis in her working group. The interview with Winkeljann promoted
      our project, which aimed to utilize spray-dried lipid nanoparticles (LNPs) for efficient delivery to the lung. By engaging with RNhale, we
      sought to understand the nuances of their nano-embedded microparticle technology and how it could enhance our delivery systems.  </p>],
    insights: [<p>RNhale's technology leverages advanced spray drying techniques to stabilize and deliver RNA therapeutics. During our interview,
      Winkeljann detailed several crucial aspects. Firstly, the stability and shelf-life of spray-dried LNPs are remarkable. RNhale’s siRNA
      formulations have maintained their integrity for up to 18 months at room temperature, and although specific data for mRNA is still pending,
      this suggests a promising shelf-life for mRNA formulations under similar conditions. The spray drying process itself involves mixing an ethanol
      phase containing lipids with an aqueous phase containing RNA. This mixture is then spray-dried, forming LNPs as tiny spherical particles.
      Key parameters for this process include maintaining an internal drying temperature of around 100 °C and using excipients like lactose to
      preserve the nanoparticles' structure and function​ <TabScrollLink tab="rnhale" scrollId="desc-1" num="1" />. </p>,
    <p>Ensuring the integrity and efficiency of the LNPs involves various methods, including gel electrophoresis, blotting, and functional readouts through transfection assays.
      After drying, the nanoparticles retain their spherical structure, which resembles that of "golf balls" under scanning electron microscopy (SEM)<TabScrollLink tab="rnhale" scrollId="desc-1" num="1" />.
      Moreover, RNhale employs artificial intelligence to optimize LNP formulations and predict the best drying conditions, reducing the need for
      extensive wet lab work. This AI-driven approach enhances efficiency and reliability in developing therapeutic nanoparticles. </p>],
    implementation: [
      <p>The interview with Dr. Benjamin Winkeljann from RNhale provided invaluable insights that will significantly enhance our project
        focused on mRNA delivery to the lungs using spray-dried LNPs. By seeking to integrate their proven techniques and innovative approach
        to spray-dry LNPs, we are optimistic about achieving superior stability, efficacy, and scalability in our therapeutic delivery systems.  </p>
    ],
    pictureurl_aim: "https://static.igem.wiki/teams/5247/photos/hp/hp-rnhale-zoom.png",
    pictureurl_interview: "https://static.igem.wiki/teams/5247/photos/for-wiki-texts/del-interview-rnhale/paper-overview.jpg",
    pictureurl_implementation: "https://static.igem.wiki/teams/5247/photos/for-wiki-texts/del-interview-rnhale/paper-sem.jpg",
    references: <RnhaleSources />,
    summary: "",
    months: ""
  },
  {
    title: "XXX",
    vorname: "David",
    nachnname: "Liu",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "Influence of research by David Liu on our design decisions ",
    interviewtabid: "liu",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    vorname: "Steffen Bira and",
    nachnname: "Serra Gürcan from Corden Pharma",
    job: "Associate director",
    affiliation: "Corden Pharma",
    pictureurl: pics['placeholder'],
    tag: "Industry",
    heading: "Lipid Nanoparticles in Gene Therapy: perspectives from Corden Pharma ",
    interviewtabid: "corden",
    cardtext: "",
    language: "de",
    quote: "X",
    aimofcontact: [<p>The goal of the discussion with Steffen Bira and Serra Gürcan from Corden Pharma was to gain insight into the design, stability, and practical application of lipid nanoparticles (LNPs) for use in gene therapy. The conversation focused on the possibility of using Corden Pharma’s LNP starter kits, understanding the factors affecting the stability of LNPs, and exploring options for incorporating antibodies into LNPs to target specific cells. </p>],
    insights: [<p>Steffen Bira and Serra Gürcan of Corden Pharma[Link Corden Pharmahttps://cordenpharma.com/] indicated that our planned spray drying approach of LNPs has not been extensively explored within their operations. The company focuses primarily on the aseptic fill and finish of LNPs, particularly for injectable formulations. However, they acknowledged the potential for spray drying and recommended consulting with specialized companies to assess the feasibility.
      The stability of the lipids used in LNPs during the spray drying process was also identified as an area requiring further investigation.
      The stability of LNPs, in particular in the context of the shear forces encountered in inhalation therapy, was identified as a critical factor. Corden Pharma highlighted that while the stability of individual lipid components can be evaluated, the stability of a complete LNP formulation containing RNA or other payloads must be empirically tested. The company put forward the suggestion that cryoprotectants and varying temperature conditions might be considered to
      enhance the stability of LNPs during processing. Corden Pharma outlined the process used to select the lipids included in their LNP starter kits, nothing that these combinations are based on established interactions and research findings, particularly in RNA-containing formulations. The kits are designed to facilitate the creation of stable LNPs by providing materials that have been tested for their physical-chemical properties, encapsulation efficiency, and potency. Furthermore, the company highlighted that a single LNP starter kit can be used for multiple batches, offering a practical solution for experimental work.
      When asked about modifying lipid components within LNP formulations, Corden Pharma suggested that exploring alternative lipids and other components could be beneficial for improving stability and efficacy, depending on the specific needs of the project. We discussed the availability of various lipids, including derivatives of cholesterol, which might enhance transfection efficiency in certain cell types. Corden Pharma confirmed that it is also possible to incorporate antibodies into LNPs, either during the initial preparation phase or by incubating antibodies with formed LNPs to achieve surface localization.
      While they did not have hands-on experience in this specific application, they referenced existing studies that could provide further guidance.
      Corden Pharma clarified that their role as a Contract Development and Manufacturing Organization (CDMO) is focused on providing services
      for the production of active pharmaceutical ingredients (APIs) and excipients, rather than developing therapeutic products. They advised that intellectual property (IP) considerations are crucial when selecting lipids for LNP formulations, especially in commercial applications, as many lipids are patented. Companies pursuing gene therapy projects should ensure that the lipids they choose are free from IP restrictions or be prepared to pay associated fees.
      The possibility of establishing a collaborative relationship was discussed, with Corden Pharma open to the idea of offering discounts on LNP starter kits or other materials in exchange for recognition in publications or other forms of acknowledgment. This proposal is subject to internal approval and would be pursued further through direct communication. </p>],
    implementation: [<p>The cooperation with Cordon Pharma provided invaluable insights for the project, particularly regarding the selection of lipids critical LNP stability and the potential applications of LNPs in gene therapy. Our initial approach involved utilising the Cayman kit, which proved to be suboptimal for the intended delivery of our Primeguide. The Corden Pharma kit #2 offers enhanced delivery efficiency thanks to its cutting-edge lipid components, including cationic lipids that boost cellular uptake and auxiliary lipids
      that reinforce the LNP structure. However, we have subsequently updated our approach and now use the Corden Pharma Kit, which builds on these benefits by including even more optimised lipid formulations. This change allows us to further improve the robustness and stability of our LNP formulations. The insights gained from the survey will significantly influence our testing process and enable us to optimise the delivery of therapeutic agents and improve overall treatment efficacy. </p>],
    summary: "",
    months: ""
  },
  {
    vorname: "Mattijs",
    nachnname: "Bulcaen",
    job: "PhD Researcher at Laboratory for Molecular Virology & Gene Therapy",
    affiliation: "KU Leuven",
    pictureurl: pics['mattijs'],
    tag: "Academia",
    heading: "",
    interviewtabid: "mattijsvisit",
    cardtext: "",
    language: "en",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Oliver",
    nachnname: "Dräger",
    job: "Bielefeld University",
    affiliation: "Research Group Cellular Neurophysiology",
    pictureurl: pics['draeger'],
    tag: "Academia",
    heading: "",
    interviewtabid: "patchclamp",
    cardtext: "",
    language: "de",
    quote: "",
    aimofcontact: "",

    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "Nils",
    nachnname: "Berelsmann",
    job: "",
    affiliation: "University of Bielefeld",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "Focus on adapting expression strategies for Fanzor nickases and exploring the potential of Pichia pastoris (SMD1163) for SpuFz1 nickase variants ",
    interviewtabid: "nberelsmann",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "Michael",
    nachnname: "Johannfunke",
    job: "Representative body for severely disabled persons",
    affiliation: "University Bielefeld",
    pictureurl: pics['johannfunke'],
    tag: "Academia",
    heading: "urgent requirement for a hygiene concept for students with disabilities and immunocompromised employees ",
    interviewtabid: "johannfunke",
    cardtext: "",
    quote: "The implementation of the hygiene concept is proving more difficult than expected due to the bureaucracy at the university. Nevertheless, the interview gave us a good insight into this labyrinth of regulations and we got started the prozess of implementation.",
    quoteVorname: "Vera",
    quoteNachname: "Köhler",
    aimofcontact: [<p>We contacted the university because of the urgent need to address the issue of hygiene for students and staff, particularly those with immunocomprised students and staff. There was a need to develop an effective hygiene concept to ensure the health and safety of these people. We developed this concept in collaboration with Max, our CF friend. [Link] </p>],
    insights: [<p>We learnt that our hygiene concept is very well-developed. But although a well-developed hygiene concept is already existing, strategic development and a step-by-step approach are needed. In particular, the step-by-step implementation was emphasized, like starting with equipping the toilets. Bureaucratic hurdles, such as the need to apply to the rectorate, were identified as a major challenge. In addition, it became clear that there is a great need for sanitary facilities and facilities for the disabled, especially due to the needs of students and staff with health problems. Interaction and networking with other universities was also considered valuable. </p>],
    implementation: [<p>The next phase of developing a new hygiene concept is to maintain contact with Mr. Johannfunke in order to continue to advance the hygiene concept in collaboration. The strategic approach entails the incremental implementation of measures, exemplified by the establishment of the inaugural toilet facility within the main building. It is of the utmost importance to ensure the uninterrupted implementation of the hygiene concept. In order to achieve this, it is essential to draw upon the existing plans and measures that have already been implemented in new buildings.  We are working on advancing the plans at a higher level and are in regular dialogue with the Central contact point Barrier-free in order to overcome bureaucratic hurdles and actively promote the topic. Furthermore, it is necessary to intensify lobbying work in order to gain greater support for this issue at both the university and political levels. </p>],
    language: "de",
    interview: <>
      <QaBox q="What do you think of our hygiene concept and our plan?" a="This is a very acute problem. It particularly affects students with disabilities and immune-compromised staff, such as those with cancer or cystic fibrosis, who are forced to work from home. The problem is: Employees can work from home, but students cannot. There is a great need for hygiene measures, as contact must be avoided to minimise the risk of infection." />
      <QaBox q="What are the challenges in implementing the hygiene concept?" a="There is a lack of strategic development, although your hygiene concept is well developed. It is necessary to proceed in small steps, e.g. starting with a toilet in the main building. However, bureaucracy is a major obstacle. To be implemented, an application has to be submitted to the rectorate, and these processes are often lengthy and complicated." />
      <QaBox q="What is the current situation at our university?" a="While some progress has been made with the installation of additional toilets and disabled-friendly toilets in new buildings, there is as yet no overarching strategy in place to guide future developments. Furthermore, the lack of clarity regarding the mission statement and objectives leaves room for ambiguity. The duty of care that employers have towards employees is established, yet the situation is regulated differently with regards to students. The possibility of receiving compensation for disadvantages is open, but is frequently seen as inadequate." />
      <QaBox q="What are the next steps in implementing the hygiene concept?" a="It is essential that the concept be implemented in small, strategic steps. At the same time, it is vital that the rectorate and other decision-makers be consulted on a regular basis to ensure that this matter remains at the forefront of discussions. Furthermore, it is of great importance to engage in political lobbying to secure additional support for this issue." />
    </>,
    summary: "We got in touch because there was an acute hygiene problem for particularly vulnerable groups like immunocomprised persons at the university. We learnt from the exchange that despite a well-developed hygiene policy, strategic steps are still needed, especially to overcome bureaucratic hurdles. We have integrated these lessons into our project by focusing on continuous collaboration with the Central contact point Barrier-free and other decision-makers.",
    months: ""
  },
  {
    title: "Dr.",
    vorname: "Sriram",
    nachnname: "Vaidyanathan ",
    job: "Principle investigator at Nationwide Children’s Hospital and assistant professor Pediatric’s at the Ohio State University College of Medicine ",
    affiliation: "Nationwide Children’s Hospital",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "F508del mutation confirmed as the most common CFTR mutation worldwide, including Asia, supporting the efficacy of existing therapies for the majority of patients. ",
    interviewtabid: "sriram",
    language: "en",
    cardtext: "",
    quote: "I think you're thinking about it the right way.[...] I would have talked to all of the exact people that you have already spoken with.",
    aimofcontact: [<p>The objective of this contact was to gather further information about cystic fibrosis (CF) in Asia, with a particular focus on understanding potential data biases, identifying common mutations, exploring the available medications, and assessing the diagnostic practices in the region. </p>],
    insights: [<p>The talk with Sriram revealed that, although cystic fibrosis (CF) is relatively uncommon in Asia compared to other disease like sickle cell disease, it nevertheless exhibits considerable genetic diversity. The identification of different mutations in the CFTR gene across the region has revealed that the F508del mutation is the most common, a finding that aligns with global patterns. However, in Asian populations, other rare mutations are also prevalent, which presents unique challenges in diagnosis and treatment.
      Additionally, it was found that environmental factors, such as air pollution, serve to exacerbate the symptoms of CF, particularly in densely populated regions, thereby further complicating the management of the disease. This emphasises the necessity for further research on CF that is specifically tailored to the needs of different regions, including improvements in diagnostic techniques and the development of treatments that are more closely aligned with the characteristics of the populations in question. </p>],
    implementation: [<p>The data were incorporated by confirming that the F508del mutation is not only the most common in Europe but also globally, including in Asia, highlighting a broader perspective and contributing to a significant horizon expansion in understanding the mutation's worldwide prevalence. This finding lends support to the idea that existing therapies targeting the F508del mutation will be effective for many patients worldwide, thereby providing a solid foundation for treatment. As a starting point, this is promising, but future efforts will focus on adapting therapies to address other, rarer mutations found in specific populations.
    </p>],
    summary: "The contact provided valuable insights into cystic fibrosis (CF) in Asia and confirmed that the F508del mutation is the most common, as it is globally. However, the genetic diversity observed in Asia, together with the exacerbation of symptoms by environmental factors such as air pollution, highlights the need for more region-specific research. Future efforts will focus on refining treatments for rarer mutations and improving diagnostic accuracy in Asian populations.",
    months: ""
  },
  {
    title: "",
    vorname: "Philipp",
    nachnname: "Kühnel",
    job: "PhD student in the Otorhinolaryngology working group at Bielefeld University",
    affiliation: "Universität Bielefeld",
    pictureurl: pics['kühnel'],
    tag: "Academia",
    heading: "Philipp Kühnel’s guidance significantly improved our culture protocols and experimental outcomes, particularly in maintaining ALI cultures and addressing fungal contamination issues.",
    interviewtabid: "pkuehnel",
    cardtext: "",
    quote: "x",
    aimofcontact: [<p>The aim of our contact with Philipp Kühnel, a PhD student from the Otorhinolaryngology working group of Bielefeld University, was to gain expertise in working with primary cultures, particularly focusing on air-liquid interface (ALI) cultures. Given his experience in this area, we sought his guidance to ensure that we were following best practices and to address any technical challenges we might encounter.</p>],
    insights: [<p>Through our discussions with Philipp, we gained valuable insights into the optimal conditions for cultivating primary cells and maintaining ALI cultures. He provided practical advice on troubleshooting of common issues, such as cell differentiation and culture stability, which were crucial for the success of our experiments. We also maintained close contact to exchange information about fungi that frequently contaminate ALI cultures. The expertise shared on combating these fungal contaminations was particularly valuable and greatly enhanced our understanding of effective prevention and treatment methods. </p>],
    implementation: [<p>We incorporated Philipp’s advice by refining our culture protocols, particularly adjusting the conditions for ALI cultures to improve cell differentiation and overall culture health. This directly enhanced the reliability of our experimental results, ensuring that our work with primary cultures was both accurate and reproducible. </p>],
    language: "de",
    summary: "The contact aimed to leverage Philipp’s expertise in ALI cultures to improve our experimental protocols Gained insights into optimizing conditions for primary cell cultures and managing common challenges like fungal contamination",
    months: ""
  },
  {
    title: "",
    vorname: "Timm",
    nachnname: "Weber",
    job: "Quality Manager | Immunologist",
    affiliation: " Biobank OWL (Bielefeld and Lippe)",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "Discussed the processes involved in the storage, processing, and security of patient samples.",
    interviewtabid: "timm",
    cardtext: "",
    quote: "A biobank is not just a collection of samples; it's a bridge between patient trust and scientific discovery, ensuring that valuable biological data is safeguarded while contributing to future research.",
    aimofcontact: "Contact was established with Timm for the purpose of gaining deeper insights into the functioning of the biobank and of deepening our understanding of the processing of patient samples.",
    insights: "We were provided with invaluable insights into the quality and project management of the biobank and storage of patient samples. It was of particular interest to note that Biobank OWL occupies a distinctive position in this context, insofar as a trustee is not a mandatory figure within its system and is therefore not provided for as a standard component. However, Biobank OWL has elected to integrate a trustee in order to enhance the security standards for the safeguarding of patient data. This illustrates the biobank's dedication to ensuring the optimal protection and security of sensitive patient data.",
    implementation: "The insights gained have facilitated a deeper comprehension of the significance of quality management in the processing of patient samples. This understanding has been integrated into our project processes, thereby enhancing the accuracy and reliability of our procedures. ",
    summary: "The interview focused on understanding the operations of the Biobank OWL, particularly in the areas of quality management and sample processing. Provided a detailed overview of biobank activities, including sample collection, storage conditions, and data protection measures",
    language: "de",
    interview: <>
      <QaBox q="Can you briefly explain to us what exactly a biobank is and what its main tasks are?"
        a="A biobank is a specialized facility that collects, stores, and manages biological samples and associated data for research purposes. Each biobank is unique in its operations and functions. In Bielefeld and Lippe, the Biobank BOWL (Biobank OWL) is responsible for the storage of patient samples. The Data Integration Centre (DIZ) stores data pertaining to these samples. A trustee oversees the pseudonymisation of data, acting as an interface between BOWL and DIZ, ensuring that patient data cannot be directly linked to patient samples." />
      <QaBox q="What types of samples are collected in your biobank and for what research purposes are they used?"
        a="The biobank collects a wide variety of samples, including blood, stool, and soil. Samples may be gathered for specific research projects or for establishing a general repository under 'broad consent.' Researchers wishing to use these samples must apply to the 'use access committee,' which evaluates whether the requested samples and data can be released for their research." />
      <QaBox q="How large is your biobank? How many samples do you currently store and how many new samples are added on average?"
        a="The biobank is still in the process of establishing itself and has not yet reached its full sample capacity. However, it is anticipated to accumulate a significant number of samples in the near future, with several thousand samples expected to be analyzed in dedicated sessions." />
      <QaBox q="What requirements and criteria must be met for a sample to be included in your biobank?" a="Samples must be processed according to highly detailed protocols, and regular audits are conducted to ensure compliance with all standards." />
      <QaBox q="Which other research institutions or biobanks do you cooperate with and what form does this cooperation take?"
        a="Biobank OWL has a second location in Lippe, in addition to Bielefeld. Collaborations exist with the DIZ, the Treuhand, and three university hospitals. It is anticipated that cooperation with other working groups will increase in the future." />
      <QaBox q="What specific storage conditions (e.g. temperature, humidity) must be observed for different sample types?"
        a="Samples are stored under various temperature conditions, including -20°C, -80°C, and -150°C, along with the use of liquid nitrogen." />
      <QaBox q="How do you ensure that the samples remain stable and usable over longer periods of time?"
        a="Samples are stored in nitrogen for long-term stability." />
      <QaBox q="What encryption techniques or data protection measures are used in your biobank to prevent unauthorized access to patient data? Are there special regulations for the anonymisation of data and how is it ensured that patients cannot be traced?"
        a="Pseudonyms are created using specialized software such as CentraXX or REDcap to protect patient data." />
      <QaBox q="What rights do patients have in relation to their samples, and how are these rights safeguarded in your biobank?"
        a="Patients have the right to revoke their consent at any time, which can be done at the clinic or biobank. The trustee, acting as an intermediary, will notify BOWL and DIZ to destroy the corresponding samples or data." />
    </>,
    months: ""
  },
  {
    title: "",
    vorname: "Nils",
    nachnname: "Berelsmann",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "nberelsmann",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "",
    nachnname: "Hammer",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "hammerkai",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "Prof.Dr.",
    vorname: "Zoya",
    nachnname: "Ingatova",
    job: "Group Leader",
    affiliation: "Institute of Biochemistry and Molecular Biology at Hamburg University",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "Shaping the Future of Genetic Therapy: An interview with Prof. Dr. Zoya Ignatova",
    interviewtabid: "ignatova",
    cardtext: "",
    quote: "Precision is key to minimizing side effects and ensuring the safety of your therapy.",
    aimofcontact: "We conducted the interview with Prof. Dr. Zoya Ignatova and Dr. Nikhil Bharti from the Institute of Biochemistry and Molecular Biology at the University of Hamburg, seeking to deepen our understanding of their research on cystic fibrosis (CF) and explore additional CF mutations, as well as to learn more about cell culture techniques specific to CF research, since they send us the CFBE41o- cell line. Our aim was also to gather more information about their approaches in CF research, particularly their focus on treating genetic mutations like nonsense mutations, which are highly prevalent in CF.",
    insights: [<p>We were struck by Ignatova’s story about founding the iGEM team in Hamburg. Her passion for fostering creativity and innovation in science was inspiring. On a technical level, their advice on cell culture was incredibly practical and immediately useful. Dr. Nikhil Bharti explained how they handle CFBE41o- cells and ALI (air-liquid interface) cell culture. This advice directly addressed the challenges we’ve faced in our own lab, giving us a method to improve our cell culture success rates. During our interview with Prof. Dr. Zoya Ignatova and Dr. Nikhil Bharti, their innovative approach to cystic fibrosis (CF) therapy, particularly "read-through" and tRNA-based therapies, stood out. "Read-through" therapies aim to bypass premature stop codons that prevent full protein production, offering a way to restore the function of critical proteins like CFTR in CF. This approach has the potential to treat a broad range of genetic diseases caused by similar mutations. The tRNA-based therapy is even more precise, targeting mRNA to correct faulty codons without altering the DNA, making it safer for long-term use. This flexibility, along with the ability to apply these therapies beyond CF, broadened our understanding of how such strategies can revolutionize treatments for genetic disorders. A key focus throughout the discussion was safety. Prof. Ignatova emphasized the importance of ensuring that the therapies are highly specific, targeting only the defective codons while avoiding natural stop codons to prevent uncontrolled protein production. Moreover, their careful consideration of delivery systems further demonstrated their commitment to minimizing risks like toxicity in unintended organs. Their meticulous approach to safety has influenced how we think about developing and applying these therapies, making it clear that ensuring patient safety is as critical as achieving therapeutic success.</p>],
    implementation: "Prof. Ignatova's practical advice on cell culture had a transformative impact on our project. By adopting her method for CFBE41o- cells and improving our lab's sterilization protocols, we successfully established the cell line and significantly reduced the risk of contamination. In addition, her emphasis on safety in gene therapy guided us to review our Prime Editing construct and lipid nanoparticle (LNP) design. We focused on minimizing toxicity and off-target effects while ensuring precise targeting of lung tissues and the F508del mutation of the CFTR gene, making our approach safer and more efficient",
    summary: "Test",
    language: "en",
    interview: <>
      <QaBox q="We have heard you are passionate about iGEM. What inspired you to get involved, and what has your experience been like with the competition?" a="My journey with iGEM began when I moved to Hamburg in 2014. Back then, Hamburg did not have its own iGEM team. Despite Hamburg lacking an iGEM presence, there were motivated students who were eager to establish a team. We started quite late with me as a principal instructor, around April, with the competition scheduled for October, so we had limited time. However, we managed to form a team and participate. Fortunately, we were successful in convincing the university administration to establish a steady support for the initiative, which ensured stable funding, including covering registration fees early on. This financial and logistical support gave the team the security to focus on their projects. Over the years, the Hamburg iGEM team has become a well-known and respected group at the university. It is a creative environment where students can push the boundaries of science through interesting and impactful projects. I moved on to other duties after several years of supervision, but I am proud to have played a role in its foundation. The university has recognized iGEM within the curriculum of Molecular Life Science, allowing students to earn credit points and have their work reflected on their transcripts. This acknowledgment further incentivizes students and ensures that their efforts are formally recognized." />
      <QaBox q="We have been having trouble with CFBE41o- cells not adhering well. Any advice?" a="CFBE41o- cells can be tricky when it comes to adhesion, but you do not necessarily need to coat your cell culture vessels with fibronectin unless you are doing very specific studies, such as primary culture comparisons. For seeding, we simplify the process by skipping the PBS washing step. Instead, we seed the cells directly into DMEM supplemented with 10% fetal calf serum (FCS) and streptomycin. These cells may take a few days to recover and begin adhering properly, that usually works without requiring extra coatings." />
      <QaBox q="How do you manage fungal contamination in ALI cultures?" a="Fungal contamination is one of the more frustrating challenges in cell culture because it is difficult to eliminate once it takes place. In cases of contamination, the best course of action is to shut down all ongoing cell culture work and clean everything thoroughly. You should start by running a sterilization cycle in your incubators, which ideally should reach around 180°C. This should kill any fungal spores. If your incubators do not have that capability, you will need to autoclave everything and clean all surfaces and equipment multiple times with ethanol. It is crucial to remove all traces of contamination, as fungal spores can spread rapidly. The key is prevention through rigorous cleaning and maintenance protocols, and unfortunately, sometimes the only solution is to start fresh with new cultures after a full decontamination round." />
      <QaBox q="What are you currently researching?" a="Our primary research focus is on genetic diseases caused by nonsense mutations, also known as premature termination codons (PTCs). While cystic fibrosis (CF) is a major area of interest due to its high prevalence and the impact of specific mutations like the F508del, our research extends far beyond CF. We are targeting a broader category of genetic diseases that share a common feature—early stop codons that lead to production of truncated proteins, which are non-functional. In CF, for instance, our main goal is to restore full-length CFTR protein production in primary patient-derived cells bearing various PTCs. One approach we are exploring is known as a 'read-through' therapy, which involves bypassing the premature stop codon so that the cell can continue producing the full protein. This strategy is applicable not only to CF but can be used in many other genetic disorders caused by nonsense mutations. Briefly, the read-through therapies we develop are tRNA-based therapeutic approaches, in which we design suppressor transfer RNAs (sup-tRNAs) to selectively target and read through PTCs, restoring the production of full-length disease protein without altering the natural termination codons. It is a highly specific and safe method, and because we are targeting mRNA rather than DNA, it allows for terminating the therapies by any unforeseen side effects." />
      <QaBox q="What are your downstream validation methods?" a="After we have developed a therapeutic approach, the first step is to validate whether it works at the protein level. First, we check whether the full-length protein is being produced. For CFTR, for example, we look at whether the protein is being correctly synthesized. We also conduct functional tests to ensure its functionality. For CFTR specifically, we test the activity of the ion channel by measuring ion flow through the cell membrane. Another test involves monitoring the height of the air-liquid interface (ALI) cultures, which reports on the ionic balance across the membrane. These functional tests are crucial for confirming that the therapy is not only leading to a production of the protein but is also restoring its function." />
      <QaBox q="How often would patients need to undergo this therapy?" a="Since our approach is designed to correct nonsense mutations during translation the therapy would need to be administered periodically. Based on our current understanding, we anticipate that patients might need treatment every three to four weeks, but this has to be determined in clinical settings." />
      <QaBox q="How does your tRNA-based approach address safety issues?" a="Safety is the top priority of our tRNA-based therapeutic approach. At molecular level, we ensure that the suppressor tRNAs we use are highly specific—they are engineered to target only PTCs without affecting natural stop codons, which are essential for terminating the synthesis of every protein. In addition to the specificity, we address the immune response that can be triggered by any nucleic acids, including tRNA. Generally, tRNA has a lower immunogenicity than other molecules, such as mRNA, because of its partially double-stranded structure, which reduces the activation of the innate immune reaction. Another critical safety aspect is the safety of the delivery system. We need to ensure that the tRNA reaches the right type of cells without causing toxicity or accumulating in untargeted tissues like the liver, which is a common issue with many gene therapies. We are also working on optimizing our delivery methods. This precision is key to minimizing side effects and ensuring the safety of our therapy." />
      <QaBox q="Why focus on CF research?" a="Our involvement with CF research emerged somewhat by chance. Initially, we were deeply interested in understanding the variability in disease, specifically why individuals with the same genetic mutations show different symptoms or present different disease severity. Even siblings or twins with usually similar genetic makeup exhibit different disease outcomes. CF became a focus as we delved into the molecular mechanism of CFTR biosynthesis. However, our work is not confined to CF—we are using the knowledge we gain from CF research and our expertise in protein synthesis and translation to develop treatments for other genetic diseases caused by nonsense mutations. The mechanisms behind these diseases are often similar, so the therapeutic strategies we are exploring can potentially be applied to a range of conditions." />
      <QaBox q="What do you see as the biggest challenge in translating your research to real-world applications?" a="Safety is the most critical hurdle in translating our research from the lab to clinical applications. Before any therapy can be considered for human use, we need to ensure that it is both safe and effective. In terms of efficacy, we have specific targets we need to meet for each disease. For CF, for example, you only need to restore about 10% of normal CFTR protein function to alleviate the symptoms. However, in other diseases, the therapeutic threshold is much higher, sometimes requiring near-complete protein restoration. Another significant challenge is the small number of patients affected by many rare genetic diseases, which requires regulation bodies to consider this and redefine conditions for clinical trials." />
      <QaBox q="What are good preclinical models for CF research, in your view?" a="Preclinical models are essential for testing the safety and efficacy of any new therapy. For CF research, one of the most reliable models is the patient-derived air-liquid interface (ALI) cultures, which replicate the lung environment and are mutation-specific. Primary cultures are available through the CF Foundation (USA) and allow researchers to test therapies in a context that closely mimics the human lung. While ALI cultures are excellent models, they are also challenging to grow and require about two months to be set up properly. For earlier-stage experiments, we often use simpler cell lines that are easier to handle. These lines allow us to perform studies at molecular level, such as testing how well a therapy restores protein production. While they do not fully represent the primary epithelial environment of the lungs, they are useful for initial validation steps before moving on to more complex models like ALI cultures." />
      <QaBox q="What are your thoughts on using lipid nanoparticles (LNPs) versus other delivery systems, like AAV vectors?" a="Lipid nanoparticles (LNPs) are a promising delivery system for many genetic therapies, but they have limitations. While LNPs can effectively target certain organs, such as the lungs and liver, they cannot cross the blood-brain barrier and thus unsuitable (for now) to target neuronal pathologies. For these conditions, adeno-associated viral (AAV) vectors may be more effective, as they exhibit an inherent ability to cross the blood-brain barrier. For CF specifically, we have used LNPs to deliver sup-tRNAs directly to the lungs. We teamed up with an US company that develops safe LNPs used also for vaccines. Delivery methods like intratracheal instillation—where the LNPs are introduced into the trachea—allow for targeting the lung tissue more directly, which is critical for treating CF." />
      <QaBox q="How do you view prime editing compared to other gene editing technologies?" a="Prime editing is an exciting development in the field of gene editing, but it is important to recognize that no single approach is universally superior. Technologies like prime editing, CRISPR-Cas, and our own tRNA-based therapies each have their strengths and limitations. For instance, prime editing offers a highly precise method for correcting mutations directly at the DNA level, potentially providing a one-time, lifelong cure. However, our approach, which focuses on restoring mRNA translation, does not introduce permanent changes to the genome and unforeseen, also individuum-specific side effects, can be counteracted by immediate termination of the therapy. In turn, it requires continuous re-administration over time. Ultimately, the safety and efficacy of any approach must be carefully weighed. We are not yet at a point where we can definitively rank these technologies because the field is still evolving. Each approach has potential, and the choice of which to use will likely depend on the specific disease and mutation being targeted." />
    </>,
    months: ""
  },
  {
    title: "",
    vorname: "Muko",
    nachnname: "Dino",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "dino",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "Marco",
    nachnname: "Radukic",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "radukic",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "",
    nachnname: "Psychologinnen",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "psychol",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },
  {
    title: "",
    vorname: "",
    nachnname: "Saito",
    job: "",
    affiliation: "",
    pictureurl: pics['placeholder'],
    tag: "Academia",
    heading: "",
    interviewtabid: "saito",
    cardtext: "",
    quote: "",
    aimofcontact: "",
    insights: "",
    implementation: "",
    summary: "",
    months: ""
  },

]

