import { useNavigate } from "react-router-dom";
import { useState } from "react";
import { useLoading } from "./LoadingContext";

export const useNavigation = () => {
    const navigate = useNavigate();

    const { setIsLoading, isLoading } = useLoading(); // 2. Ladezustand hier verwenden



    const goToPagesAndOpenTab = (tabId: string, path: string) => {
    
        
        navigate(`${path}?tab=${tabId}`);
        
    };
    const goToTextsAndOpenCollapsible = (collapseId: string, path: string) => {
        
        
        navigate(`${path}?collapseId=${collapseId}`);
    };
    const goToPageWithTabAndCollapsible = ({ path, tabId, collapseId }: { path: string, tabId: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };
    const goToPageWithNestedTabs = ({ path, tabId, subTabId, collapseId }: { path: string, tabId: string, subTabId?: string, collapseId?: string }) => {
        
        
        let url = `${path}?tab=${tabId}`;
        if (subTabId) {
            url += `&subTab=${subTabId}`;
        }
        if (collapseId) {
            url += `&collapseId=${collapseId}`;
        }
        navigate(url);
    };



    const goToPageWithTabAndScroll = ({ path, tabId, scrollToId }: { path: string, tabId: string, scrollToId: string }) => {
        let url = `${path}?tab=${tabId}`;
        if (scrollToId) {
            url += `&scrollTo=${scrollToId}`;
        }
        navigate(url);
    };

    const goToPageAndScroll = (scrollToId: string, path: string) => {
        
        
        navigate(`${path}?scrollTo=${scrollToId}`);
    };

    const changePageWithLoadingScreen = () => ({ path, scrollToId }: { path: string, scrollToId: string }) => {
        setIsLoading(true);
        let url = `${path}?changeTo=${scrollToId}`;
        navigate(url);

        setTimeout(() => {
            const element = document.getElementById(scrollToId);
            if (element) {
              const viewportHeight = window.innerHeight;
              const targetPosition = element.getBoundingClientRect().top + window.pageYOffset;
              const scrollToPosition = targetPosition - viewportHeight / 2 + element.clientHeight / 2;
              window.scrollTo({ top: scrollToPosition, behavior: "smooth" });
      
              // Ladezustand nach Abschluss des Scrollens beenden
              setTimeout(() => {
                setIsLoading(false);
              }, 1000); // Scrollzeit als Beispiel
            } else {
              // Falls das Element nicht gefunden wird, Ladezustand beenden
              setIsLoading(false);
            }
          }, 500); 
    };

    
    return { isLoading, changePageWithLoadingScreen,  goToPageAndScroll, setIsLoading, goToPagesAndOpenTab, goToPageWithTabAndScroll, goToPageWithNestedTabs, goToPageWithTabAndCollapsible, goToTextsAndOpenCollapsible };
};
